# -*- coding: utf-8 -*-

# Resource object code
#
# Created: qua mai 1 18:37:33 2019
#      by: The Resource Compiler for PySide2 (Qt v5.12.2)
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore

qt_resource_data = b"\
\x00\x00\xa6\xa5\
/\
* QDarkStyleShee\
t --------------\
----------------\
----------------\
----------\x0a\x0aThis\
 is the main sty\
le sheet, the pa\
lette has nine m\
ain colors.\x0aIt i\
s based on three\
 selecting color\
s, three greyish\
 (background) co\
lors\x0aplus three \
whitish (foregro\
und) colors. Eac\
h set of widgets\
 of the same\x0atyp\
e have a header \
like this:\x0a\x0a    \
----------------\
--\x0a    GroupName\
 --------\x0a    --\
----------------\
\x0a\x0aAnd each widge\
t is separated w\
ith a header lik\
e this:\x0a\x0a    QWi\
dgetName ------\x0a\
\x0aThis makes more\
 easy to find an\
d change some cs\
s field. The bas\
ic\x0aconfiguration\
 is described be\
llow.\x0a\x0a    SELEC\
TION -----------\
-\x0a\x0a        sel_l\
ight  #179AE0 #1\
48CD2 (selection\
/hover/active)\x0a \
       sel_norma\
l #3375A3 #1464A\
0 (selected)\x0a   \
     sel_dark   \
#18465D #14506E \
(selected disabl\
ed)\x0a\x0a    FOREGRO\
UND -----------\x0a\
\x0a        for_lig\
ht  #EFF0F1 #F0F\
0F0 (texts/label\
s)\x0a        for_n\
ormal         #A\
AAAAA (not used \
yet)\x0a        for\
_dark   #505F69 \
#787878 (disable\
d texts)\x0a\x0a    BA\
CKGROUND -------\
----\x0a\x0a        ba\
c_light  #4D545B\
 #505F69 (unpres\
sed)\x0a        bac\
_normal #31363B \
#32414B (border,\
 disabled, press\
ed, checked, too\
lbars, menus)\x0a  \
      bac_dark  \
 #232629 #19232D\
 (background)\x0a\x0aI\
f a stranger con\
figuration is re\
quired because o\
f a bugfix or an\
ything\x0aelse, kee\
p the comment on\
 that line to no\
bodys changed it\
, including the\x0a\
issue number.\x0a--\
----------------\
----------------\
----------------\
----------------\
--------- */\x0a\x0a\x0a\x0a\
/* QWidget -----\
----------------\
----------------\
----------------\
----------- */\x0a\x0a\
QWidget {\x0a    ba\
ckground-color: \
#19232D;\x0a    bor\
der: 0px solid #\
32414B;\x0a    padd\
ing: 0px;\x0a    co\
lor: #F0F0F0;\x0a  \
  selection-back\
ground-color: #1\
464A0;\x0a    selec\
tion-color: #F0F\
0F0;\x0a}\x0a\x0aQWidget:\
disabled {\x0a    b\
ackground-color:\
 #19232D;\x0a    co\
lor: #787878;\x0a  \
  selection-back\
ground-color: #1\
4506E;\x0a    selec\
tion-color: #787\
878;\x0a}\x0a\x0aQWidget:\
item:selected {\x0a\
    background-c\
olor: #1464A0;\x0a}\
\x0a\x0aQWidget:item:h\
over {\x0a    backg\
round-color: #14\
8CD2;\x0a    color:\
 #32414B;\x0a}\x0a\x0a/* \
QMainWindow ----\
----------------\
----------------\
----------------\
-------- */\x0a/* T\
his adjusts the \
splitter in the \
dock widget, not\
 qsplitter      \
        */\x0a\x0a\x0aQMa\
inWindow::separa\
tor {\x0a    backgr\
ound-color: #324\
14B;\x0a    border:\
 0 solid #19232D\
;\x0a    spacing: 0\
;\x0a    padding: 2\
px;\x0a}\x0a\x0aQMainWind\
ow::separator:ho\
ver {\x0a    backgr\
ound-color: #505\
F69;\x0a    border:\
 0px solid #148C\
D2;\x0a}\x0a\x0aQMainWind\
ow::separator:ho\
rizontal {\x0a    w\
idth: 5px;\x0a    m\
argin-top: 2px;\x0a\
    margin-botto\
m: 2px;\x0a    imag\
e: url(:/qss_ico\
ns/rc/Vsepartool\
bar.png);\x0a}\x0a\x0aQMa\
inWindow::separa\
tor:vertical {\x0a \
   height: 5px;\x0a\
    margin-left:\
 2px;\x0a    margin\
-right: 2px;\x0a   \
 image: url(:/qs\
s_icons/rc/Hsepa\
rtoolbar.png);\x0a}\
\x0a\x0a/* QToolTip --\
----------------\
----------------\
----------------\
------------- */\
\x0a\x0aQToolTip {\x0a   \
 background-colo\
r: #148CD2;\x0a    \
border: 1px soli\
d #19232D;\x0a    c\
olor: #19232D;\x0a \
   padding: 0;  \
 /*remove paddin\
g, for fix combo\
 box tooltip*/\x0a \
   opacity: 230;\
 /*reducing tran\
sparency to read\
 better*/\x0a}\x0a\x0a/* \
QStatusBar -----\
----------------\
----------------\
----------------\
-------- */\x0a\x0aQSt\
atusBar {\x0a    bo\
rder: 1px solid \
#32414B;\x0a    bac\
kground: #32414B\
; /*fixes spyder\
 #9120,#9121*/\x0a}\
\x0a\x0aQStatusBar QTo\
olTip {\x0a    back\
ground-color: #1\
48CD2;\x0a    borde\
r: 1px solid #19\
232D;\x0a    color:\
 #19232D;\x0a    pa\
dding: 0;   /*re\
move padding, fo\
r fix combo box \
tooltip*/\x0a    op\
acity: 230; /*re\
ducing transpare\
ncy to read bett\
er*/\x0a}\x0a\x0aQStatusB\
ar QLabel {\x0a    \
background-color\
: transparent; /\
*fixes spyder #9\
120,#9121*/\x0a}\x0a\x0a/\
* QCheckBox ----\
----------------\
----------------\
----------------\
---------- */\x0a\x0aQ\
CheckBox {\x0a    b\
ackground-color:\
 #19232D;\x0a    co\
lor: #F0F0F0;\x0a  \
  spacing: 4px;\x0a\
    outline: non\
e;\x0a    padding-t\
op: 4px;\x0a    pad\
ding-bottom: 4px\
;\x0a}\x0a\x0aQCheckBox:f\
ocus {\x0a    borde\
r: none;\x0a}\x0a\x0aQChe\
ckBox QWidget:di\
sabled {\x0a    bac\
kground-color: #\
19232D;\x0a    colo\
r: #787878;\x0a}\x0a\x0aQ\
CheckBox::indica\
tor {\x0a    margin\
-left: 4px;\x0a    \
width: 16px;\x0a   \
 height: 16px;\x0a}\
\x0a\x0aQCheckBox::ind\
icator:unchecked\
 {\x0a    image: ur\
l(:/qss_icons/rc\
/checkbox_unchec\
ked.png);\x0a}\x0a\x0aQCh\
eckBox::indicato\
r:unchecked:hove\
r,\x0aQCheckBox::in\
dicator:unchecke\
d:focus,\x0aQCheckB\
ox::indicator:un\
checked:pressed \
{\x0a    border: no\
ne;\x0a    image: u\
rl(:/qss_icons/r\
c/checkbox_unche\
cked_focus.png);\
\x0a}\x0a\x0aQCheckBox::i\
ndicator:uncheck\
ed:disabled {\x0a  \
  image: url(:/q\
ss_icons/rc/chec\
kbox_unchecked_d\
isabled.png);\x0a}\x0a\
\x0aQCheckBox::indi\
cator:checked {\x0a\
    image: url(:\
/qss_icons/rc/ch\
eckbox_checked.p\
ng);\x0a}\x0a\x0aQCheckBo\
x::indicator:che\
cked:hover,\x0aQChe\
ckBox::indicator\
:checked:focus,\x0a\
QCheckBox::indic\
ator:checked:pre\
ssed {\x0a    borde\
r: none;\x0a    ima\
ge: url(:/qss_ic\
ons/rc/checkbox_\
checked_focus.pn\
g);\x0a}\x0a\x0aQCheckBox\
::indicator:chec\
ked:disabled{\x0a  \
  image: url(:/q\
ss_icons/rc/chec\
kbox_checked_dis\
abled.png);\x0a}\x0a\x0aQ\
CheckBox::indica\
tor:indeterminat\
e {\x0a    image: u\
rl(:/qss_icons/r\
c/checkbox_indet\
erminate.png);\x0a}\
\x0a\x0aQCheckBox::ind\
icator:indetermi\
nate:disabled {\x0a\
    image: url(:\
/qss_icons/rc/ch\
eckbox_indetermi\
nate_disabled.pn\
g);\x0a}\x0a\x0aQCheckBox\
::indicator:inde\
terminate:focus,\
\x0aQCheckBox::indi\
cator:indetermin\
ate:hover,\x0aQChec\
kBox::indicator:\
indeterminate:pr\
essed {\x0a    imag\
e: url(:/qss_ico\
ns/rc/checkbox_i\
ndeterminate_foc\
us.png);\x0a}\x0a\x0a/* Q\
GroupBox -------\
----------------\
----------------\
----------------\
------- */\x0a\x0aQGro\
upBox {\x0a    font\
-weight: bold;\x0a \
   border: 1px s\
olid #32414B;\x0a  \
  border-radius:\
 4px;\x0a    paddin\
g: 4px;\x0a    marg\
in-top: 16px;\x0a}\x0a\
\x0a\x0a\x0aQGroupBox::ti\
tle {\x0a    subcon\
trol-origin: mar\
gin;\x0a    subcont\
rol-position: to\
p left;\x0a    left\
: 3px;\x0a    paddi\
ng-left: 3px;\x0a  \
  padding-right:\
 5px;\x0a    paddin\
g-top: 8px;\x0a    \
padding-bottom: \
16px;\x0a}\x0a\x0aQGroupB\
ox::indicator {\x0a\
    margin-left:\
 4px;\x0a    width:\
 16px;\x0a    heigh\
t: 16px;\x0a}\x0a\x0aQGro\
upBox::indicator\
 {\x0a    margin-le\
ft: 2px;\x0a}\x0a\x0aQGro\
upBox::indicator\
:unchecked:hover\
,\x0aQGroupBox::ind\
icator:unchecked\
:focus,\x0aQGroupBo\
x::indicator:unc\
hecked:pressed {\
\x0a    border: non\
e;\x0a    image: ur\
l(:/qss_icons/rc\
/checkbox_unchec\
ked_focus.png);\x0a\
}\x0a\x0aQGroupBox::in\
dicator:checked:\
hover,\x0aQGroupBox\
::indicator:chec\
ked:focus,\x0aQGrou\
pBox::indicator:\
checked:pressed \
{\x0a    border: no\
ne;\x0a    image: u\
rl(:/qss_icons/r\
c/checkbox_check\
ed_focus.png);\x0a}\
\x0a\x0aQGroupBox::ind\
icator:checked:d\
isabled {\x0a    im\
age: url(:/qss_i\
cons/rc/checkbox\
_checked_disable\
d.png);\x0a}\x0a\x0aQGrou\
pBox::indicator:\
unchecked:disabl\
ed {\x0a    image: \
url(:/qss_icons/\
rc/checkbox_unch\
ecked_disabled.p\
ng);\x0a}\x0a\x0a/* QRadi\
oButton --------\
----------------\
----------------\
----------------\
--- */\x0a\x0aQRadioBu\
tton {\x0a    backg\
round-color: #19\
232D;\x0a    color:\
 #F0F0F0;\x0a    sp\
acing: 0;\x0a    pa\
dding: 0;\x0a    bo\
rder: none;\x0a    \
outline: none;\x0a}\
\x0a\x0aQRadioButton:f\
ocus {\x0a    borde\
r: none;\x0a}\x0a\x0aQRad\
ioButton:disable\
d {\x0a    backgrou\
nd-color: #19232\
D;\x0a    color: #7\
87878;\x0a    borde\
r: none;\x0a    out\
line: none;\x0a}\x0a\x0aQ\
RadioButton QWid\
get {\x0a    backgr\
ound-color: #192\
32D;\x0a    color: \
#F0F0F0;\x0a    spa\
cing: 0px;\x0a    p\
adding: 0px;\x0a   \
 outline: none;\x0a\
    border: none\
;\x0a}\x0a\x0aQRadioButto\
n::indicator {\x0a \
   border: none;\
\x0a    outline: no\
ne;\x0a    margin-b\
ottom: 2px;\x0a    \
width: 25px;\x0a   \
 height: 25px;\x0a}\
\x0a\x0aQRadioButton::\
indicator:unchec\
ked {\x0a    image:\
 url(:/qss_icons\
/rc/radio_unchec\
ked.png);\x0a}\x0a\x0aQRa\
dioButton::indic\
ator:unchecked:h\
over,\x0aQRadioButt\
on::indicator:un\
checked:focus,\x0aQ\
RadioButton::ind\
icator:unchecked\
:pressed {\x0a    b\
order: none;\x0a   \
 outline: none;\x0a\
    image: url(:\
/qss_icons/rc/ra\
dio_unchecked_fo\
cus.png);\x0a}\x0a\x0aQRa\
dioButton::indic\
ator:checked {\x0a \
   border: none;\
\x0a    outline: no\
ne;\x0a    image: u\
rl(:/qss_icons/r\
c/radio_checked.\
png);\x0a}\x0a\x0aQRadioB\
utton::indicator\
:checked:hover,\x0a\
QRadioButton::in\
dicator:checked:\
focus,\x0aQRadioBut\
ton::indicator:c\
hecked:pressed {\
\x0a    border: non\
e;\x0a    outline: \
none;\x0a    image:\
 url(:/qss_icons\
/rc/radio_checke\
d_focus.png);\x0a}\x0a\
\x0aQRadioButton::i\
ndicator:checked\
:disabled {\x0a    \
outline: none;\x0a \
   image: url(:/\
qss_icons/rc/rad\
io_checked_disab\
led.png);\x0a}\x0a\x0aQRa\
dioButton::indic\
ator:unchecked:d\
isabled {\x0a    im\
age: url(:/qss_i\
cons/rc/radio_un\
checked_disabled\
.png);\x0a}\x0a\x0a/* QMe\
nuBar ----------\
----------------\
----------------\
----------------\
----- */\x0a\x0aQMenuB\
ar {\x0a    backgro\
und-color: #3241\
4B;\x0a    padding:\
 2px;\x0a    border\
: 1px solid #192\
32D;\x0a    color: \
#F0F0F0;\x0a}\x0a\x0aQMen\
uBar:focus {\x0a   \
 border: 1px sol\
id #148CD2;\x0a}\x0a\x0aQ\
MenuBar::item {\x0a\
    background: \
transparent;\x0a   \
 padding: 4px;\x0a}\
\x0a\x0aQMenuBar::item\
:selected {\x0a    \
padding: 4px;\x0a  \
  background: tr\
ansparent;\x0a    b\
order: 0px solid\
 #32414B;\x0a}\x0a\x0aQMe\
nuBar::item:pres\
sed {\x0a    paddin\
g: 4px;\x0a    bord\
er: 0px solid #3\
2414B;\x0a    backg\
round-color: #14\
8CD2;\x0a    color:\
 #F0F0F0;\x0a    ma\
rgin-bottom: 0px\
;\x0a    padding-bo\
ttom: 0px;\x0a}\x0a\x0a/*\
 QMenu ---------\
----------------\
----------------\
----------------\
--------- */\x0a\x0aQM\
enu {\x0a    border\
: 0px solid #324\
14B;\x0a    color: \
#F0F0F0;\x0a    mar\
gin: 0px;\x0a}\x0a\x0aQMe\
nu::separator {\x0a\
    height: 2px;\
\x0a    background-\
color: #505F69;\x0a\
    color: #F0F0\
F0;\x0a    padding-\
left: 4px;\x0a    m\
argin-left: 2px;\
\x0a    margin-righ\
t: 2px;\x0a}\x0a\x0aQMenu\
::icon {\x0a    mar\
gin: 0px;\x0a    pa\
dding-left:4px;\x0a\
}\x0a\x0aQMenu::item {\
\x0a    padding: 4p\
x 24px 4px 24px;\
\x0a    border: 1px\
 transparent #32\
414B;  /* reserv\
e space for sele\
ction border */\x0a\
}\x0a\x0aQMenu::item:s\
elected {\x0a    co\
lor: #F0F0F0;\x0a}\x0a\
\x0a\x0a\x0aQMenu::indica\
tor {\x0a    width:\
 12px;\x0a    heigh\
t: 12px;\x0a    pad\
ding-left:6px;\x0a}\
\x0a\x0a/* non-exclusi\
ve indicator = c\
heck box style i\
ndicator (see QA\
ctionGroup::setE\
xclusive) */\x0a\x0aQM\
enu::indicator:n\
on-exclusive:unc\
hecked {\x0a    ima\
ge: url(:/qss_ic\
ons/rc/checkbox_\
unchecked.png);\x0a\
}\x0a\x0aQMenu::indica\
tor:non-exclusiv\
e:unchecked:sele\
cted {\x0a    image\
: url(:/qss_icon\
s/rc/checkbox_un\
checked_disabled\
.png);\x0a}\x0a\x0aQMenu:\
:indicator:non-e\
xclusive:checked\
 {\x0a    image: ur\
l(:/qss_icons/rc\
/checkbox_checke\
d.png);\x0a}\x0a\x0aQMenu\
::indicator:non-\
exclusive:checke\
d:selected {\x0a   \
 image: url(:/qs\
s_icons/rc/check\
box_checked_disa\
bled.png);\x0a}\x0a\x0a/*\
 exclusive indic\
ator = radio but\
ton style indica\
tor (see QAction\
Group::setExclus\
ive) */\x0a\x0aQMenu::\
indicator:exclus\
ive:unchecked {\x0a\
    image: url(:\
/qss_icons/rc/ra\
dio_unchecked.pn\
g);\x0a}\x0a\x0aQMenu::in\
dicator:exclusiv\
e:unchecked:sele\
cted {\x0a    image\
: url(:/qss_icon\
s/rc/radio_unche\
cked_disabled.pn\
g);\x0a}\x0a\x0aQMenu::in\
dicator:exclusiv\
e:checked {\x0a    \
image: url(:/qss\
_icons/rc/radio_\
checked.png);\x0a}\x0a\
\x0aQMenu::indicato\
r:exclusive:chec\
ked:selected {\x0a \
   image: url(:/\
qss_icons/rc/rad\
io_checked_disab\
led.png);\x0a}\x0a\x0aQMe\
nu::right-arrow \
{\x0a    margin: 5p\
x;\x0a    image: ur\
l(:/qss_icons/rc\
/right_arrow.png\
)\x0a}\x0a\x0a/* QAbstrac\
tItemView ------\
----------------\
----------------\
----------------\
 */\x0a\x0aQAbstractIt\
emView {\x0a    alt\
ernate-backgroun\
d-color: #19232D\
;\x0a    color: #F0\
F0F0;\x0a    border\
: 1px solid #324\
14B;\x0a    border-\
radius: 4px;\x0a}\x0a\x0a\
QAbstractItemVie\
w QLineEdit {\x0a  \
  padding: 2px;\x0a\
}\x0a\x0a/* QAbstractS\
crollArea ------\
----------------\
----------------\
-------------- *\
/\x0a\x0aQAbstractScro\
llArea {\x0a    bac\
kground-color: #\
19232D;\x0a    bord\
er: 1px solid #3\
2414B;\x0a    borde\
r-radius: 4px;\x0a \
   padding: 4px;\
\x0a    color: #F0F\
0F0;\x0a}\x0a\x0aQAbstrac\
tScrollArea:disa\
bled {\x0a    color\
: #787878;\x0a}\x0a\x0a/*\
 QScrollArea ---\
----------------\
----------------\
----------------\
--------- */\x0a\x0aQS\
crollArea QWidge\
t QWidget:disabl\
ed {\x0a    backgro\
und-color: #1923\
2D;\x0a}\x0a\x0a/* QScrol\
lBar -----------\
----------------\
----------------\
----------------\
-- */\x0a\x0aQScrollBa\
r:horizontal {\x0a \
   height: 16px;\
\x0a    margin: 2px\
 16px 2px 16px;\x0a\
    border: 1px \
solid #32414B;\x0a \
   border-radius\
: 4px;\x0a    backg\
round-color: #19\
232D;\x0a}\x0a\x0aQScroll\
Bar::handle:hori\
zontal {\x0a    bac\
kground-color: #\
787878;\x0a    bord\
er: 1px solid #3\
2414B;\x0a    borde\
r-radius: 4px;\x0a \
   min-width: 8p\
x;\x0a\x0a}\x0a\x0aQScrollBa\
r::handle:horizo\
ntal:hover {\x0a   \
 background-colo\
r: #148CD2;\x0a    \
border: 1px soli\
d #148CD2;\x0a    b\
order-radius: 4p\
x;\x0a    min-width\
: 8px;\x0a}\x0a\x0aQScrol\
lBar::add-line:h\
orizontal {\x0a    \
margin: 0px 0px \
0px 0px;\x0a    bor\
der-image: url(:\
/qss_icons/rc/ri\
ght_arrow_disabl\
ed.png);\x0a    wid\
th: 10px;\x0a    he\
ight: 10px;\x0a    \
subcontrol-posit\
ion: right;\x0a    \
subcontrol-origi\
n: margin;\x0a}\x0a\x0aQS\
crollBar::sub-li\
ne:horizontal {\x0a\
    margin: 0px \
3px 0px 3px;\x0a   \
 border-image: u\
rl(:/qss_icons/r\
c/left_arrow_dis\
abled.png);\x0a    \
height: 10px;\x0a  \
  width: 10px;\x0a \
   subcontrol-po\
sition: left;\x0a  \
  subcontrol-ori\
gin: margin;\x0a}\x0a\x0a\
QScrollBar::add-\
line:horizontal:\
hover,\x0aQScrollBa\
r::add-line:hori\
zontal:on {\x0a    \
border-image: ur\
l(:/qss_icons/rc\
/right_arrow.png\
);\x0a    height: 1\
0px;\x0a    width: \
10px;\x0a    subcon\
trol-position: r\
ight;\x0a    subcon\
trol-origin: mar\
gin;\x0a}\x0a\x0aQScrollB\
ar::sub-line:hor\
izontal:hover,\x0aQ\
ScrollBar::sub-l\
ine:horizontal:o\
n {\x0a    border-i\
mage: url(:/qss_\
icons/rc/left_ar\
row.png);\x0a    he\
ight: 10px;\x0a    \
width: 10px;\x0a   \
 subcontrol-posi\
tion: left;\x0a    \
subcontrol-origi\
n: margin;\x0a}\x0a\x0aQS\
crollBar::up-arr\
ow:horizontal,\x0aQ\
ScrollBar::down-\
arrow:horizontal\
 {\x0a    backgroun\
d: none;\x0a}\x0a\x0aQScr\
ollBar::add-page\
:horizontal,\x0aQSc\
rollBar::sub-pag\
e:horizontal {\x0a \
   background: n\
one;\x0a}\x0a\x0aQScrollB\
ar:vertical {\x0a  \
  background-col\
or: #19232D;\x0a   \
 width: 16px;\x0a  \
  margin: 16px 2\
px 16px 2px;\x0a   \
 border: 1px sol\
id #32414B;\x0a    \
border-radius: 4\
px;\x0a}\x0a\x0aQScrollBa\
r::handle:vertic\
al {\x0a    backgro\
und-color: #7878\
78;\x0a    border: \
1px solid #32414\
B;\x0a    min-heigh\
t: 8px;\x0a    bord\
er-radius: 4px;\x0a\
}\x0a\x0aQScrollBar::h\
andle:vertical:h\
over {\x0a    backg\
round-color: #14\
8CD2;\x0a    border\
: 1px solid #148\
CD2;\x0a    border-\
radius: 4px;\x0a   \
 min-height: 8px\
;\x0a\x0a}\x0a\x0aQScrollBar\
::sub-line:verti\
cal {\x0a    margin\
: 3px 0px 3px 0p\
x;\x0a    border-im\
age: url(:/qss_i\
cons/rc/up_arrow\
_disabled.png);\x0a\
    height: 10px\
;\x0a    width: 10p\
x;\x0a    subcontro\
l-position: top;\
\x0a    subcontrol-\
origin: margin;\x0a\
}\x0a\x0aQScrollBar::a\
dd-line:vertical\
 {\x0a    margin: 3\
px 0px 3px 0px;\x0a\
    border-image\
: url(:/qss_icon\
s/rc/down_arrow_\
disabled.png);\x0a \
   height: 10px;\
\x0a    width: 10px\
;\x0a    subcontrol\
-position: botto\
m;\x0a    subcontro\
l-origin: margin\
;\x0a}\x0a\x0aQScrollBar:\
:sub-line:vertic\
al:hover,\x0aQScrol\
lBar::sub-line:v\
ertical:on {\x0a   \
 border-image: u\
rl(:/qss_icons/r\
c/up_arrow.png);\
\x0a    height: 10p\
x;\x0a    width: 10\
px;\x0a    subcontr\
ol-position: top\
;\x0a    subcontrol\
-origin: margin;\
\x0a}\x0a\x0aQScrollBar::\
add-line:vertica\
l:hover,\x0aQScroll\
Bar::add-line:ve\
rtical:on {\x0a    \
border-image: ur\
l(:/qss_icons/rc\
/down_arrow.png)\
;\x0a    height: 10\
px;\x0a    width: 1\
0px;\x0a    subcont\
rol-position: bo\
ttom;\x0a    subcon\
trol-origin: mar\
gin;\x0a}\x0a\x0aQScrollB\
ar::up-arrow:ver\
tical,\x0aQScrollBa\
r::down-arrow:ve\
rtical {\x0a    bac\
kground: none;\x0a}\
\x0a\x0aQScrollBar::ad\
d-page:vertical,\
\x0aQScrollBar::sub\
-page:vertical {\
\x0a    background:\
 none;\x0a}\x0a\x0a/* QTe\
xtEdit----------\
----------------\
----------------\
----------------\
----- */\x0a\x0aQTextE\
dit {\x0a    backgr\
ound-color: #192\
32D;\x0a    color: \
#F0F0F0;\x0a    bor\
der: 1px solid #\
32414B;\x0a}\x0a\x0aQText\
Edit:hover {\x0a   \
 border: 1px sol\
id #148CD2;\x0a    \
color: #F0F0F0;\x0a\
}\x0a\x0aQTextEdit:sel\
ected {\x0a    back\
ground: #1464A0;\
\x0a    color: #324\
14B;\x0a}\x0a\x0a/* QPlai\
nTextEdit ------\
----------------\
----------------\
----------------\
--- */\x0a\x0aQPlainTe\
xtEdit {\x0a    bac\
kground-color: #\
19232D;\x0a    colo\
r: #F0F0F0;\x0a    \
border-radius: 4\
px;\x0a    border: \
1px solid #32414\
B;\x0a}\x0a\x0aQPlainText\
Edit:hover {\x0a   \
 border: 1px sol\
id #148CD2;\x0a    \
color: #F0F0F0;\x0a\
}\x0a\x0aQPlainTextEdi\
t:selected {\x0a   \
 background: #14\
64A0;\x0a    color:\
 #32414B;\x0a}\x0a\x0a/* \
QSizeGrip ------\
----------------\
----------------\
----------------\
--------- */\x0a\x0aQS\
izeGrip {\x0a    im\
age: url(:/qss_i\
cons/rc/sizegrip\
.png);\x0a    width\
: 12px;\x0a    heig\
ht: 12px;\x0a}\x0a\x0a/* \
QStackedWidget -\
----------------\
----------------\
----------------\
-------- */\x0a\x0aQSt\
ackedWidget {\x0a  \
  padding: 4px;\x0a\
    border: 1px \
solid #32414B;\x0a \
   border: 1px s\
olid #19232D;\x0a}\x0a\
\x0a/* QToolBar ---\
----------------\
----------------\
----------------\
------------ */\x0a\
\x0aQToolBar {\x0a    \
background-color\
: #32414B;\x0a    b\
order-bottom: 1p\
x solid #19232D;\
\x0a    padding: 2p\
x;\x0a    font-weig\
ht: bold;\x0a}\x0a\x0aQTo\
olBar QToolButto\
n{\x0a    backgroun\
d-color: #32414B\
;\x0a}\x0a\x0aQToolBar::h\
andle:horizontal\
 {\x0a    width: 6p\
x;\x0a    image: ur\
l(:/qss_icons/rc\
/Hmovetoolbar.pn\
g);\x0a}\x0a\x0aQToolBar:\
:handle:vertical\
 {\x0a    height: 6\
px;\x0a    image: u\
rl(:/qss_icons/r\
c/Vmovetoolbar.p\
ng);\x0a}\x0a\x0aQToolBar\
::separator:hori\
zontal {\x0a    wid\
th: 3px;\x0a    ima\
ge: url(:/qss_ic\
ons/rc/Hsepartoo\
lbar.png);\x0a}\x0a\x0aQT\
oolBar::separato\
r:vertical {\x0a   \
 height: 3px;\x0a  \
  image: url(:/q\
ss_icons/rc/Vsep\
artoolbar.png);\x0a\
}\x0a\x0aQToolButton#q\
t_toolbar_ext_bu\
tton {\x0a    backg\
round: #32414B;\x0a\
    border: 0px;\
\x0a    color: #F0F\
0F0;\x0a    image: \
url(:/qss_icons/\
rc/right_arrow.p\
ng);\x0a}\x0a\x0a/* QAbst\
ractSpinBox ----\
----------------\
----------------\
----------------\
--- */\x0a\x0aQAbstrac\
tSpinBox {\x0a    b\
ackground-color:\
 #19232D;\x0a    bo\
rder: 1px solid \
#32414B;\x0a    col\
or: #F0F0F0;\x0a   \
 padding-top: 2p\
x;     /* This f\
ix  103, 111*/\x0a \
   padding-botto\
m: 2px;  /* This\
 fix  103, 111*/\
\x0a    padding-lef\
t: 4px;\x0a    padd\
ing-right: 4px;\x0a\
    border-radiu\
s: 4px;\x0a    /* m\
in-width: 5px; r\
emoved to fix 10\
9 */\x0a}\x0a\x0aQAbstrac\
tSpinBox:up-butt\
on {\x0a    backgro\
und-color: trans\
parent #19232D;\x0a\
    subcontrol-o\
rigin: border;\x0a \
   subcontrol-po\
sition: top righ\
t;\x0a    border-le\
ft: 1px solid #3\
2414B;\x0a    margi\
n: 1px;\x0a}\x0a\x0aQAbst\
ractSpinBox::up-\
arrow,\x0aQAbstract\
SpinBox::up-arro\
w:disabled,\x0aQAbs\
tractSpinBox::up\
-arrow:off {\x0a   \
 image: url(:/qs\
s_icons/rc/up_ar\
row_disabled.png\
);\x0a    width: 9p\
x;\x0a    height: 9\
px;\x0a}\x0a\x0aQAbstract\
SpinBox::up-arro\
w:hover {\x0a    im\
age: url(:/qss_i\
cons/rc/up_arrow\
.png);\x0a}\x0a\x0aQAbstr\
actSpinBox:down-\
button {\x0a    bac\
kground-color: t\
ransparent #1923\
2D;\x0a    subcontr\
ol-origin: borde\
r;\x0a    subcontro\
l-position: bott\
om right;\x0a    bo\
rder-left: 1px s\
olid #32414B;\x0a  \
  margin: 1px;\x0a}\
\x0a\x0aQAbstractSpinB\
ox::down-arrow,\x0a\
QAbstractSpinBox\
::down-arrow:dis\
abled,\x0aQAbstract\
SpinBox::down-ar\
row:off {\x0a    im\
age: url(:/qss_i\
cons/rc/down_arr\
ow_disabled.png)\
;\x0a    width: 9px\
;\x0a    height: 9p\
x;\x0a}\x0a\x0aQAbstractS\
pinBox::down-arr\
ow:hover {\x0a    i\
mage: url(:/qss_\
icons/rc/down_ar\
row.png);\x0a}\x0a\x0aQAb\
stractSpinBox:ho\
ver{\x0a    border:\
 1px solid #148C\
D2;\x0a    color: #\
F0F0F0;\x0a}\x0a\x0aQAbst\
ractSpinBox:sele\
cted {\x0a    backg\
round: #1464A0;\x0a\
    color: #3241\
4B;\x0a}\x0a\x0a/* ------\
----------------\
----------------\
----------------\
----------------\
-- */\x0a/* DISPLAY\
S --------------\
----------------\
----------------\
----------------\
- */\x0a/* --------\
----------------\
----------------\
----------------\
----------------\
 */\x0a\x0a/* QLabel -\
----------------\
----------------\
----------------\
----------------\
 */\x0a\x0aQLabel {\x0a  \
  background-col\
or: #19232D;\x0a   \
 border: 0px sol\
id #32414B;\x0a    \
padding: 2px;\x0a  \
  margin: 0px;\x0a \
   color: #F0F0F\
0\x0a}\x0a\x0aQLabel::dis\
abled {\x0a    back\
ground-color: #1\
9232D;\x0a    borde\
r: 0px solid #32\
414B;\x0a    color:\
 #787878;\x0a}\x0a\x0a/* \
QTextBrowser ---\
----------------\
----------------\
----------------\
-------- */\x0a\x0aQTe\
xtBrowser {\x0a    \
background-color\
: #19232D;\x0a    b\
order: 1px solid\
 #32414B;\x0a    co\
lor: #F0F0F0;\x0a  \
  border-radius:\
 4px;\x0a}\x0a\x0aQTextBr\
owser:disabled {\
\x0a    background-\
color: #19232D;\x0a\
    border: 1px \
solid #32414B;\x0a \
   color: #78787\
8;\x0a    border-ra\
dius: 4px;\x0a}\x0a\x0aQT\
extBrowser:hover\
,\x0aQTextBrowser:!\
hover,\x0aQTextBrow\
ser::selected,\x0aQ\
TextBrowser::pre\
ssed {\x0a    borde\
r: 1px solid #32\
414B;\x0a}\x0a\x0a/* QGra\
phicsView ------\
----------------\
----------------\
----------------\
--- */\x0a\x0aQGraphic\
sView {\x0a    back\
ground-color: #1\
9232D;\x0a    borde\
r: 1px solid #32\
414B;\x0a    color:\
 #F0F0F0;\x0a    bo\
rder-radius: 4px\
;\x0a}\x0a\x0aQGraphicsVi\
ew:disabled {\x0a  \
  background-col\
or: #19232D;\x0a   \
 border: 1px sol\
id #32414B;\x0a    \
color: #787878;\x0a\
    border-radiu\
s: 4px;\x0a}\x0a\x0aQGrap\
hicsView:hover,\x0a\
QGraphicsView:!h\
over,\x0aQGraphicsV\
iew::selected,\x0aQ\
GraphicsView::pr\
essed {\x0a    bord\
er: 1px solid #3\
2414B;\x0a}\x0a\x0a/* QCa\
lendarWidget ---\
----------------\
----------------\
----------------\
----- */\x0a\x0aQCalen\
darWidget {\x0a    \
border: 1px soli\
d #32414B;\x0a    b\
order-radius: 4p\
x;\x0a}\x0a\x0aQCalendarW\
idget:disabled {\
\x0a    background-\
color: #19232D;\x0a\
    color: #7878\
78;\x0a}\x0a\x0a/* QLCDNu\
mber -----------\
----------------\
----------------\
----------------\
-- */\x0a\x0aQLCDNumbe\
r {\x0a    backgrou\
nd-color: #19232\
D;\x0a    color: #F\
0F0F0;\x0a}\x0a\x0aQLCDNu\
mber:disabled {\x0a\
    background-c\
olor: #19232D;\x0a \
   color: #78787\
8;\x0a}\x0a\x0a/* QProgre\
ssBar ----------\
----------------\
----------------\
----------------\
- */\x0a\x0aQProgressB\
ar {\x0a    backgro\
und-color: #1923\
2D;\x0a    border: \
1px solid #32414\
B;\x0a    color: #F\
0F0F0;\x0a    borde\
r-radius: 4px;\x0a \
   text-align: c\
enter;\x0a}\x0a\x0aQProgr\
essBar:disabled \
{\x0a    background\
-color: #19232D;\
\x0a    border: 1px\
 solid #32414B;\x0a\
    color: #7878\
78;\x0a    border-r\
adius: 4px;\x0a    \
text-align: cent\
er;\x0a}\x0a\x0aQProgress\
Bar::chunk {\x0a   \
 background-colo\
r: #1464A0;\x0a    \
color: #19232D;\x0a\
    border-radiu\
s: 4px;\x0a}\x0a\x0aQProg\
ressBar::chunk:d\
isabled {\x0a    ba\
ckground-color: \
#14506E;\x0a    col\
or: #787878;\x0a   \
 border-radius: \
4px;\x0a}\x0a\x0a\x0a/* ----\
----------------\
----------------\
----------------\
----------------\
---- */\x0a/* BUTTO\
NS -------------\
----------------\
----------------\
----------------\
--- */\x0a/* ------\
----------------\
----------------\
----------------\
----------------\
-- */\x0a\x0a/* QPushB\
utton ----------\
----------------\
----------------\
----------------\
-- */\x0a\x0aQPushButt\
on {\x0a    backgro\
und-color: #505F\
69 ;\x0a    border:\
 1px solid #3241\
4B;\x0a    color: #\
F0F0F0;\x0a    bord\
er-radius: 4px;\x0a\
    padding: 3px\
;\x0a    outline: n\
one;\x0a}\x0a\x0aQPushBut\
ton:disabled {\x0a \
   background-co\
lor: #32414B;\x0a  \
  border: 1px so\
lid #32414B;\x0a   \
 color: #787878;\
\x0a    border-radi\
us: 4px;\x0a    pad\
ding: 3px;\x0a}\x0a\x0a\x0aQ\
PushButton:check\
ed {\x0a    backgro\
und-color: #3241\
4B;\x0a    border: \
1px solid #32414\
B;\x0a    border-ra\
dius: 4px;\x0a    p\
adding: 3px;\x0a   \
 outline: none;\x0a\
}\x0a\x0aQPushButton:c\
hecked:disabled \
{\x0a    background\
-color: #19232D;\
\x0a    border: 1px\
 solid #32414B;\x0a\
    color: #7878\
78;\x0a    border-r\
adius: 4px;\x0a    \
padding: 3px;\x0a  \
  outline: none;\
\x0a}\x0a\x0aQPushButton:\
:menu-indicator \
{\x0a    subcontrol\
-origin: padding\
;\x0a    subcontrol\
-position: botto\
m right;\x0a    bot\
tom: 4px;\x0a}\x0a\x0aQPu\
shButton:pressed\
 {\x0a    backgroun\
d-color: #19232D\
;\x0a    border: 1p\
x solid #19232D;\
\x0a}\x0a\x0aQPushButton:\
hover,\x0aQPushButt\
on:checked:hover\
{\x0a    border: 1p\
x solid #148CD2;\
\x0a    color: #F0F\
0F0;\x0a}\x0a\x0aQPushBut\
ton:pressed:hove\
r{\x0a    border: 1\
px solid #1464A0\
;\x0a}\x0a\x0aQPushButton\
:selected,\x0aQPush\
Button:checked:s\
elected{\x0a    bac\
kground: #1464A0\
;\x0a    color: #32\
414B;\x0a}\x0a\x0a/* QToo\
lButton --------\
----------------\
----------------\
----------------\
---- */\x0a\x0aQToolBu\
tton {\x0a    backg\
round-color: tra\
nsparent;\x0a    bo\
rder: 1px solid \
#32414B;\x0a    bor\
der-radius: 4px;\
\x0a    margin: 0px\
;\x0a    padding: 2\
px;\x0a}\x0a\x0aQToolButt\
on:checked {\x0a   \
 background-colo\
r: #19232D;\x0a    \
border: 1px soli\
d #19232D;\x0a}\x0a\x0aQT\
oolButton:presse\
d {\x0a    backgrou\
nd-color: #19232\
D;\x0a    border: 1\
px solid #19232D\
;\x0a\x0a}\x0a\x0aQToolButto\
n:disabled {\x0a   \
 border: 1px sol\
id #32414B;\x0a}\x0a\x0aQ\
ToolButton:hover\
,\x0aQToolButton:ch\
ecked:hover{\x0a   \
 border: 1px sol\
id #148CD2;\x0a}\x0aQT\
oolButton:presse\
d:hover{\x0a    bor\
der: 1px solid #\
1464A0;\x0a}\x0a\x0a/* th\
e subcontrols be\
low are used onl\
y in the MenuBut\
tonPopup mode */\
\x0a\x0aQToolButton[po\
pupMode=\x221\x22] {\x0a \
   padding: 2px;\
\x0a    padding-rig\
ht: 12px;     /*\
 only for MenuBu\
ttonPopup */\x0a   \
 border: 1px sol\
id #32414B;   /*\
 make way for th\
e popup button *\
/\x0a    border-rad\
ius: 4px;\x0a}\x0a\x0a/* \
The subcontrol b\
elow is used onl\
y in the Instant\
Popup or Delayed\
Popup mode */\x0a\x0aQ\
ToolButton[popup\
Mode=\x222\x22] {\x0a    \
padding: 2px;\x0a  \
  padding-right:\
 12px;      /* o\
nly for InstantP\
opup */\x0a    bord\
er: 1px solid #3\
2414B;    /* mak\
e way for the po\
pup button */\x0a}\x0a\
\x0aQToolButton::me\
nu-button {\x0a    \
padding: 2px;\x0a  \
  border-radius:\
 4px;\x0a    border\
: 1px solid #324\
14B;\x0a    border-\
top-right-radius\
: 4px;\x0a    borde\
r-bottom-right-r\
adius: 4px;\x0a    \
/* 16px width + \
4px for border =\
 20px allocated \
above */\x0a    wid\
th: 16px;\x0a    ou\
tline: none;\x0a}\x0a\x0a\
QToolButton::men\
u-button:hover,\x0a\
QToolButton::men\
u-button:checked\
:hover {\x0a    bor\
der: 1px solid #\
148CD2;\x0a}\x0a\x0aQTool\
Button::menu-ind\
icator {\x0a    ima\
ge: url(:/qss_ic\
ons/rc/down_arro\
w.png);\x0a    top:\
 -8px;     /* sh\
ift it a bit */\x0a\
    left: -4px; \
   /* shift it a\
 bit */\x0a}\x0a\x0aQTool\
Button::menu-arr\
ow {\x0a    image: \
url(:/qss_icons/\
rc/down_arrow.pn\
g);\x0a}\x0a\x0aQToolButt\
on::menu-arrow:o\
pen {\x0a    border\
: 1px solid #324\
14B;\x0a}\x0a\x0a/* QComm\
andLinkButton --\
----------------\
----------------\
----------------\
--- */\x0a\x0aQCommand\
LinkButton {\x0a   \
 background-colo\
r: transparent;\x0a\
    border: 1px \
solid #32414B;\x0a \
   color: #F0F0F\
0;\x0a    border-ra\
dius: 4px;\x0a    p\
adding: 0px;\x0a   \
 margin: 0px;\x0a}\x0a\
\x0aQCommandLinkBut\
ton:disabled {\x0a \
   background-co\
lor: transparent\
;\x0a    color: #78\
7878;\x0a}\x0a\x0a/* ----\
----------------\
----------------\
----------------\
----------------\
---- */\x0a/* INPUT\
S - NO FIELDS --\
----------------\
----------------\
----------------\
--- */\x0a/* ------\
----------------\
----------------\
----------------\
----------------\
-- */\x0a\x0a/* QCombo\
box ------------\
----------------\
----------------\
----------------\
-- */\x0aQComboBox \
{\x0a    border: 1p\
x solid #32414B;\
\x0a    border-radi\
us: 4px;\x0a    sel\
ection-backgroun\
d-color: #1464A0\
;\x0a    padding-le\
ft: 4px;\x0a    pad\
ding-right: 4px;\
\x0a    min-height:\
 1.5em;  /*   fi\
x #103, #111    \
  */\x0a    /* padd\
ing-top: 2px;   \
  removed to fix\
 #132 */\x0a    /* \
padding-bottom: \
2px;  removed to\
 fix #132 */\x0a   \
 /* min-width: 7\
5px;      remove\
d to fix #109 */\
\x0a}\x0a\x0aQComboBox QA\
bstractItemView \
{\x0a    background\
-color: #19232d;\
\x0a    border-radi\
us: 4px;\x0a    bor\
der: 1px solid #\
32414B;\x0a    sele\
ction-color: #14\
8CD2;\x0a    select\
ion-background-c\
olor: #32414B;\x0a}\
\x0a\x0aQComboBox:disa\
bled {\x0a    backg\
round-color: #19\
232D;\x0a    color:\
 #787878;\x0a}\x0a\x0aQCo\
mboBox:hover{\x0a  \
  border: 1px so\
lid #148CD2;\x0a}\x0a\x0a\
QComboBox:on {\x0a \
   selection-bac\
kground-color: #\
19232D;\x0a}\x0a\x0a/* Ne\
eded to remove i\
ndicator - fix #\
132 */\x0aQComboBox\
::indicator {\x0a  \
  background-col\
or:transparent;\x0a\
    selection-ba\
ckground-color:t\
ransparent;\x0a    \
color:transparen\
t;\x0a    selection\
-color:transpare\
nt;\x0a}\x0a\x0a/* Needed\
 to remove indic\
ator - fix #132 \
*/\x0aQComboBox::it\
em:alternate {\x0a \
   background: #\
19232D;\x0a}\x0a\x0aQComb\
oBox::item:check\
ed {\x0a    font-we\
ight: bold;\x0a}\x0a\x0aQ\
ComboBox::item:s\
elected {\x0a    bo\
rder: 0px solid \
transparent;\x0a}\x0a\x0a\
QComboBox::drop-\
down {\x0a    subco\
ntrol-origin: pa\
dding;\x0a    subco\
ntrol-position: \
top right;\x0a    w\
idth: 20px;\x0a    \
border-left-widt\
h: 0px;\x0a    bord\
er-left-color: #\
32414B;\x0a    bord\
er-left-style: s\
olid;\x0a    border\
-top-right-radiu\
s: 3px;\x0a    bord\
er-bottom-right-\
radius: 3px;\x0a}\x0a\x0a\
QComboBox::down-\
arrow {\x0a    imag\
e: url(:/qss_ico\
ns/rc/down_arrow\
_disabled.png);\x0a\
}\x0a\x0aQComboBox::do\
wn-arrow:on,\x0aQCo\
mboBox::down-arr\
ow:hover,\x0aQCombo\
Box::down-arrow:\
focus {\x0a    imag\
e: url(:/qss_ico\
ns/rc/down_arrow\
.png);\x0a}\x0a\x0a/* QSl\
ider -----------\
----------------\
----------------\
----------------\
----- */\x0a\x0aQSlide\
r:disabled {\x0a   \
 background: #19\
232D;\x0a}\x0a\x0aQSlider\
:focus {\x0a    bor\
der: none;\x0a}\x0a\x0aQS\
lider::groove:ho\
rizontal {\x0a    b\
ackground: #3241\
4B;\x0a    border: \
1px solid #32414\
B;\x0a    height: 4\
px;\x0a    margin: \
0px;\x0a    border-\
radius: 4px;\x0a}\x0a\x0a\
QSlider::sub-pag\
e:horizontal {\x0a \
   background: #\
1464A0;\x0a    bord\
er: 1px solid #3\
2414B;\x0a    heigh\
t: 4px;\x0a    marg\
in: 0px;\x0a    bor\
der-radius: 4px;\
\x0a}\x0a\x0aQSlider::sub\
-page:horizontal\
:disabled {\x0a    \
background: #145\
06E;\x0a}\x0a\x0aQSlider:\
:handle:horizont\
al {\x0a    backgro\
und: #787878;\x0a  \
  border: 1px so\
lid #32414B;\x0a   \
 width: 8px;\x0a   \
 height: 8px;\x0a  \
  margin: -8px 0\
;\x0a    border-rad\
ius: 4px;\x0a}\x0a\x0aQSl\
ider::handle:hor\
izontal:hover {\x0a\
    background: \
#148CD2;\x0a    bor\
der: 1px solid #\
148CD2;\x0a}\x0a\x0aQSlid\
er::groove:verti\
cal {\x0a    backgr\
ound: #32414B;\x0a \
   border: 1px s\
olid #32414B;\x0a  \
  width: 4px;\x0a  \
  margin: 0px;\x0a \
   border-radius\
: 4px;\x0a}\x0a\x0aQSlide\
r::sub-page:vert\
ical {\x0a    backg\
round: #1464A0;\x0a\
    border: 1px \
solid #32414B;\x0a \
   width: 4px;\x0a \
   margin: 0px;\x0a\
    border-radiu\
s: 4px;\x0a}\x0a\x0aQSlid\
er::sub-page:ver\
tical:disabled {\
\x0a    background:\
 #14506E;\x0a}\x0a\x0aQSl\
ider::handle:ver\
tical {\x0a    back\
ground: #787878;\
\x0a    border: 1px\
 solid #32414B;\x0a\
    width: 8px;\x0a\
    height: 8px;\
\x0a    margin: 0 -\
8px;\x0a    border-\
radius: 4px;\x0a}\x0a\x0a\
QSlider::handle:\
vertical:hover {\
\x0a    background:\
 #148CD2;\x0a    bo\
rder: 1px solid \
#148CD2;\x0a}\x0a\x0a/* Q\
Line -----------\
----------------\
----------------\
----------------\
------- */\x0a\x0aQLin\
eEdit {\x0a    back\
ground-color: #1\
9232D;\x0a    paddi\
ng-top: 2px;    \
 /* This QLineEd\
it fix  103, 111\
 */\x0a    padding-\
bottom: 2px;  /*\
 This QLineEdit \
fix  103, 111 */\
\x0a    padding-lef\
t: 4px;\x0a    padd\
ing-right: 4px;\x0a\
    border-style\
: solid;\x0a    bor\
der: 1px solid #\
32414B;\x0a    bord\
er-radius: 4px;\x0a\
    color: #F0F0\
F0;\x0a}\x0a\x0aQLineEdit\
:disabled {\x0a    \
background-color\
: #19232D;\x0a    c\
olor: #787878;\x0a}\
\x0a\x0aQLineEdit:hove\
r{\x0a    border: 1\
px solid #148CD2\
;\x0a    color: #F0\
F0F0;\x0a}\x0a\x0aQLineEd\
it:selected{\x0a   \
 background: #14\
64A0;\x0a    color:\
 #32414B;\x0a}\x0a\x0a/* \
QTabWiget ------\
----------------\
----------------\
----------------\
-------- */\x0a\x0aQTa\
bWidget {\x0a    pa\
dding: 2px;\x0a    \
selection-backgr\
ound-color: #324\
14B;\x0a}\x0a\x0a\x0aQTabWid\
get QWidget QWid\
get       /* add\
 wanted borders \
fix #141, #126, \
#123 */\x0aQTabWidg\
et QFrame {\x0a    \
border: 1px soli\
d #32414B;\x0a}\x0a\x0aQT\
abWidget QLabel \
{\x0a    border: 0p\
x solid #32414B;\
 /* label derive\
d from frame, re\
move border #141\
 */\x0a}\x0a\x0aQTabWidge\
t::pane {\x0a    bo\
rder: 1px solid \
#32414B;\x0a    bor\
der-radius: 4px;\
\x0a    padding: 0p\
x;              \
 /* fixes double\
 border inside p\
ane wit pyqt5 */\
\x0a    margin: 0px\
;\x0a}\x0a\x0aQTabWidget:\
:pane:selected {\
\x0a    background-\
color: #32414B;\x0a\
    border: 1px \
solid #1464A0;\x0a}\
\x0a\x0a/* QTabBar ---\
----------------\
----------------\
----------------\
------------- */\
\x0a\x0aQTabBar {\x0a    \
qproperty-drawBa\
se: 0;\x0a    borde\
r-radius: 4px;\x0a \
   margin: 0px;\x0a\
    padding: 2px\
;\x0a    border: 0;\
\x0a\x0a    /* left: 5\
px; move to the \
right by 5px - r\
emoved for fix *\
/\x0a    }\x0a\x0aQTabBar\
::close-button {\
\x0a    border: 0;\x0a\
    margin: 2px;\
\x0a    padding: 0;\
\x0a    image: url(\
:/qss_icons/rc/c\
lose.png);\x0a}\x0a\x0aQT\
abBar::close-but\
ton:hover {\x0a    \
image: url(:/qss\
_icons/rc/close-\
hover.png);\x0a}\x0a\x0aQ\
TabBar::close-bu\
tton:pressed {\x0a \
   image: url(:/\
qss_icons/rc/clo\
se-pressed.png);\
\x0a}\x0a\x0a/* QTabBar::\
tab - selected -\
----------------\
----------------\
-------------- *\
/\x0a\x0aQTabBar::tab:\
top:selected:dis\
abled {\x0a    bord\
er-bottom: 3px s\
olid #14506E;\x0a  \
  color: #787878\
;\x0a    background\
-color: #32414B;\
\x0a}\x0a\x0aQTabBar::tab\
:bottom:selected\
:disabled {\x0a    \
border-top: 3px \
solid #14506E;\x0a \
   color: #78787\
8;\x0a    backgroun\
d-color: #32414B\
;\x0a}\x0a\x0aQTabBar::ta\
b:left:selected:\
disabled {\x0a    b\
order-left: 3px \
solid #14506E;\x0a \
   color: #78787\
8;\x0a    backgroun\
d-color: #32414B\
;\x0a}\x0a\x0aQTabBar::ta\
b:right:selected\
:disabled {\x0a    \
border-right: 3p\
x solid #14506E;\
\x0a    color: #787\
878;\x0a    backgro\
und-color: #3241\
4B;\x0a}\x0a\x0a/* QTabBa\
r::tab - !select\
ed and disabled \
----------------\
----------------\
-- */\x0a\x0aQTabBar::\
tab:top:!selecte\
d:disabled {\x0a   \
 border-bottom: \
3px solid #19232\
D;\x0a    color: #7\
87878;\x0a    backg\
round-color: #19\
232D;\x0a}\x0a\x0aQTabBar\
::tab:bottom:!se\
lected:disabled \
{\x0a    border-top\
: 3px solid #192\
32D;\x0a    color: \
#787878;\x0a    bac\
kground-color: #\
19232D;\x0a}\x0a\x0aQTabB\
ar::tab:left:!se\
lected:disabled \
{\x0a    border-rig\
ht: 3px solid #1\
9232D;\x0a    color\
: #787878;\x0a    b\
ackground-color:\
 #19232D;\x0a}\x0a\x0aQTa\
bBar::tab:right:\
!selected:disabl\
ed {\x0a    border-\
left: 3px solid \
#19232D;\x0a    col\
or: #787878;\x0a   \
 background-colo\
r: #19232D;\x0a}\x0a\x0a/\
* QTabBar::tab -\
 selected ------\
----------------\
----------------\
--------- */\x0a\x0aQT\
abBar::tab:top:!\
selected {\x0a    b\
order-bottom: 2p\
x solid #19232D;\
\x0a    margin-top:\
 2px;\x0a}\x0a\x0aQTabBar\
::tab:bottom:!se\
lected {\x0a    bor\
der-top: 2px sol\
id #19232D;\x0a    \
margin-bottom: 3\
px;\x0a}\x0a\x0aQTabBar::\
tab:left:!select\
ed {\x0a    border-\
left: 2px solid \
#19232D;\x0a    mar\
gin-right: 2px;\x0a\
}\x0a\x0aQTabBar::tab:\
right:!selected \
{\x0a    border-rig\
ht: 2px solid #1\
9232D;\x0a    margi\
n-left: 2px;\x0a}\x0a\x0a\
\x0aQTabBar::tab:to\
p {\x0a    backgrou\
nd-color: #32414\
B;\x0a    color: #F\
0F0F0;\x0a    margi\
n-left: 2px;\x0a   \
 padding-left: 4\
px;\x0a    padding-\
right: 4px;\x0a    \
padding-top: 2px\
;\x0a    padding-bo\
ttom: 2px;\x0a    m\
in-width: 5px;\x0a \
   border-bottom\
: 3px solid #324\
14B;\x0a    border-\
top-left-radius:\
 3px;\x0a    border\
-top-right-radiu\
s: 3px;\x0a}\x0a\x0aQTabB\
ar::tab:top:sele\
cted {\x0a    backg\
round-color: #50\
5F69;\x0a    color:\
 #F0F0F0;\x0a    bo\
rder-bottom: 3px\
 solid #1464A0;\x0a\
    border-top-l\
eft-radius: 3px;\
\x0a    border-top-\
right-radius: 3p\
x;\x0a}\x0a\x0aQTabBar::t\
ab:top:!selected\
:hover {\x0a    bor\
der: 1px solid #\
148CD2;\x0a    bord\
er-bottom: 3px s\
olid #148CD2;\x0a  \
  padding: 0px;\x0a\
}\x0a\x0aQTabBar::tab:\
bottom {\x0a    col\
or: #F0F0F0;\x0a   \
 border-top: 3px\
 solid #32414B;\x0a\
    background-c\
olor: #32414B;\x0a \
   margin-left: \
2px;\x0a    padding\
-left: 4px;\x0a    \
padding-right: 4\
px;\x0a    padding-\
top: 2px;\x0a    pa\
dding-bottom: 2p\
x;\x0a    border-bo\
ttom-left-radius\
: 3px;\x0a    borde\
r-bottom-right-r\
adius: 3px;\x0a    \
min-width: 5px;\x0a\
}\x0a\x0aQTabBar::tab:\
bottom:selected \
{\x0a    color: #F0\
F0F0;\x0a    backgr\
ound-color: #505\
F69;\x0a    border-\
top: 3px solid #\
1464A0;\x0a    bord\
er-bottom-left-r\
adius: 3px;\x0a    \
border-bottom-ri\
ght-radius: 3px;\
\x0a}\x0a\x0aQTabBar::tab\
:bottom:!selecte\
d:hover {\x0a    bo\
rder: 1px solid \
#148CD2;\x0a    bor\
der-top: 3px sol\
id #148CD2;\x0a    \
padding: 0px;\x0a}\x0a\
\x0aQTabBar::tab:le\
ft {\x0a    color: \
#F0F0F0;\x0a    bac\
kground-color: #\
32414B;\x0a    marg\
in-top: 2px;\x0a   \
 padding-left: 2\
px;\x0a    padding-\
right: 2px;\x0a    \
padding-top: 4px\
;\x0a    padding-bo\
ttom: 4px;\x0a    b\
order-top-right-\
radius: 3px;\x0a   \
 border-bottom-r\
ight-radius: 3px\
;\x0a    min-height\
: 5px;\x0a}\x0a\x0aQTabBa\
r::tab:left:sele\
cted {\x0a    color\
: #F0F0F0;\x0a    b\
ackground-color:\
 #505F69;\x0a    bo\
rder-left: 3px s\
olid #1464A0;\x0a  \
  border-top-rig\
ht-radius: 3px;\x0a\
    border-botto\
m-right-radius: \
3px;\x0a}\x0a\x0aQTabBar:\
:tab:left:!selec\
ted:hover {\x0a    \
border: 1px soli\
d #148CD2;\x0a    b\
order-left: 3px \
solid #148CD2;\x0a \
   padding: 0px;\
\x0a}\x0a\x0aQTabBar::tab\
:right {\x0a    col\
or: #F0F0F0;\x0a   \
 background-colo\
r: #32414B;\x0a    \
margin-top: 2px;\
\x0a    padding-lef\
t: 2px;\x0a    padd\
ing-right: 2px;\x0a\
    padding-top:\
 4px;\x0a    paddin\
g-bottom: 4px;\x0a \
   border-top-le\
ft-radius: 3px;\x0a\
    border-botto\
m-left-radius: 3\
px;\x0a    min-heig\
ht: 5px;\x0a}\x0a\x0aQTab\
Bar::tab:right:s\
elected {\x0a    co\
lor: #F0F0F0;\x0a  \
  background-col\
or: #505F69;\x0a   \
 border-right: 3\
px solid #1464A0\
;\x0a    border-top\
-left-radius: 3p\
x;\x0a    border-bo\
ttom-left-radius\
: 3px;\x0a}\x0a\x0aQTabBa\
r::tab:right:!se\
lected:hover {\x0a \
   border: 1px s\
olid #148CD2;\x0a  \
  border-right: \
3px solid #148CD\
2;\x0a    padding: \
0px;\x0a}\x0a\x0aQTabBar \
QToolButton::rig\
ht-arrow:enabled\
 {\x0a    image: ur\
l(:/qss_icons/rc\
/right_arrow.png\
);\x0a}\x0a\x0aQTabBar QT\
oolButton::left-\
arrow:enabled {\x0a\
    image: url(:\
/qss_icons/rc/le\
ft_arrow.png);\x0a}\
\x0a\x0aQTabBar QToolB\
utton::right-arr\
ow:disabled {\x0a  \
  image: url(:/q\
ss_icons/rc/righ\
t_arrow_disabled\
.png);\x0a}\x0a\x0aQTabBa\
r QToolButton::l\
eft-arrow:disabl\
ed {\x0a    image: \
url(:/qss_icons/\
rc/left_arrow_di\
sabled.png);\x0a}\x0a\x0a\
QTabBar QToolBut\
ton{\x0a    backgro\
und-color: #3241\
4B;       /* fix\
es #136 */\x0a    w\
idth: 16px;\x0a    \
height: 16px;\x0a}\x0a\
\x0a/* QDockWiget -\
----------------\
----------------\
----------------\
------------ */\x0a\
\x0aQDockWidget {\x0a \
   outline: 1px \
solid #32414B;\x0a \
   background-co\
lor: #19232D;\x0a  \
  border: 1px so\
lid #32414B;\x0a   \
 border-radius: \
4px;\x0a    titleba\
r-close-icon: ur\
l(:/qss_icons/rc\
/close.png);\x0a   \
 titlebar-normal\
-icon: url(:/qss\
_icons/rc/undock\
.png);\x0a}\x0a\x0aQDockW\
idget::title {\x0a \
   padding: 6px;\
   /* better siz\
e for title bar \
*/\x0a    border: n\
one;\x0a    backgro\
und-color: #3241\
4B;\x0a}\x0a\x0aQDockWidg\
et::close-button\
 {\x0a    backgroun\
d-color: #32414B\
;\x0a    border-rad\
ius: 4px;\x0a    bo\
rder: none;\x0a}\x0a\x0aQ\
DockWidget::clos\
e-button:hover {\
\x0a    border: 1px\
 solid #32414B;\x0a\
}\x0a\x0aQDockWidget::\
close-button:pre\
ssed {\x0a    borde\
r: 1px solid #32\
414B;\x0a}\x0a\x0aQDockWi\
dget::float-butt\
on {\x0a    backgro\
und-color: #3241\
4B;\x0a    border-r\
adius: 4px;\x0a    \
border: none;\x0a}\x0a\
\x0aQDockWidget::fl\
oat-button:hover\
 {\x0a    border: 1\
px solid #32414B\
;\x0a}\x0a\x0aQDockWidget\
::float-button:p\
ressed {\x0a    bor\
der: 1px solid #\
32414B;\x0a}\x0a\x0a\x0a/* Q\
TreeView QTableV\
iew QListView --\
----------------\
----------------\
------- */\x0a\x0aQTre\
eView:branch:sel\
ected,\x0aQTreeView\
:branch:hover {\x0a\
    background: \
url(:/qss_icons/\
rc/transparent.p\
ng);\x0a}\x0a\x0aQTreeVie\
w::branch:has-si\
blings:!adjoins-\
item {\x0a    borde\
r-image: url(:/q\
ss_icons/rc/tran\
sparent.png);\x0a}\x0a\
\x0aQTreeView::bran\
ch:has-siblings:\
adjoins-item {\x0a \
   border-image:\
 url(:/qss_icons\
/rc/transparent.\
png);\x0a}\x0a\x0aQTreeVi\
ew::branch:!has-\
children:!has-si\
blings:adjoins-i\
tem {\x0a    border\
-image: url(:/qs\
s_icons/rc/trans\
parent.png);\x0a}\x0a\x0a\
QTreeView::branc\
h:has-children:!\
has-siblings:clo\
sed,\x0aQTreeView::\
branch:closed:ha\
s-children:has-s\
iblings {\x0a    im\
age: url(:/qss_i\
cons/rc/branch_c\
losed.png);\x0a}\x0a\x0aQ\
TreeView::branch\
:open:has-childr\
en:!has-siblings\
,\x0aQTreeView::bra\
nch:open:has-chi\
ldren:has-siblin\
gs {\x0a    image: \
url(:/qss_icons/\
rc/branch_open.p\
ng);\x0a}\x0a\x0aQTreeVie\
w::branch:has-ch\
ildren:!has-sibl\
ings:closed:hove\
r,\x0aQTreeView::br\
anch:closed:has-\
children:has-sib\
lings:hover {\x0a  \
  image: url(:/q\
ss_icons/rc/bran\
ch_closed-on.png\
);\x0a}\x0a\x0aQTreeView:\
:branch:open:has\
-children:!has-s\
iblings:hover,\x0aQ\
TreeView::branch\
:open:has-childr\
en:has-siblings:\
hover {\x0a    imag\
e: url(:/qss_ico\
ns/rc/branch_ope\
n-on.png);\x0a}\x0a\x0aQL\
istView::item:!s\
elected:hover,\x0aQ\
TreeView::item:!\
selected:hover,\x0a\
QTableView::item\
:!selected:hover\
,\x0aQColumnView::i\
tem:!selected:ho\
ver {\x0a    outlin\
e: 0;\x0a    color:\
 #148CD2;\x0a    ba\
ckground-color: \
#32414B;\x0a}\x0a\x0aQLis\
tView::item:sele\
cted:hover,\x0aQTre\
eView::item:sele\
cted:hover,\x0aQTab\
leView::item:sel\
ected:hover,\x0aQCo\
lumnView::item:s\
elected:hover {\x0a\
    background: \
#1464A0;\x0a    col\
or:  #19232D;\x0a}\x0a\
\x0aQTreeView::indi\
cator:checked,\x0aQ\
ListView::indica\
tor:checked {\x0a  \
  image: url(:/q\
ss_icons/rc/chec\
kbox_checked.png\
);\x0a}\x0a\x0aQTreeView:\
:indicator:unche\
cked,\x0aQListView:\
:indicator:unche\
cked {\x0a    image\
: url(:/qss_icon\
s/rc/checkbox_un\
checked.png);\x0a}\x0a\
\x0aQTreeView::indi\
cator:checked:ho\
ver,\x0aQTreeView::\
indicator:checke\
d:focus,\x0aQTreeVi\
ew::indicator:ch\
ecked:pressed,\x0aQ\
ListView::indica\
tor:checked:hove\
r,\x0aQListView::in\
dicator:checked:\
focus,\x0aQListView\
::indicator:chec\
ked:pressed {\x0a  \
  image: url(:/q\
ss_icons/rc/chec\
kbox_checked_foc\
us.png);\x0a}\x0a\x0aQTre\
eView::indicator\
:unchecked:hover\
,\x0aQTreeView::ind\
icator:unchecked\
:focus,\x0aQTreeVie\
w::indicator:unc\
hecked:pressed,\x0a\
QListView::indic\
ator:unchecked:h\
over,\x0aQListView:\
:indicator:unche\
cked:focus,\x0aQLis\
tView::indicator\
:unchecked:press\
ed {\x0a    image: \
url(:/qss_icons/\
rc/checkbox_unch\
ecked_focus.png)\
;\x0a}\x0a\x0aQTreeView::\
indicator:indete\
rminate:hover,\x0aQ\
TreeView::indica\
tor:indeterminat\
e:focus,\x0aQTreeVi\
ew::indicator:in\
determinate:pres\
sed,\x0aQListView::\
indicator:indete\
rminate:hover,\x0aQ\
ListView::indica\
tor:indeterminat\
e:focus,\x0aQListVi\
ew::indicator:in\
determinate:pres\
sed {\x0a    image:\
 url(:/qss_icons\
/rc/checkbox_ind\
eterminate_focus\
.png);\x0a}\x0a\x0aQTreeV\
iew::indicator:i\
ndeterminate,\x0aQL\
istView::indicat\
or:indeterminate\
 {\x0a    image: ur\
l(:/qss_icons/rc\
/checkbox_indete\
rminate.png);\x0a}\x0a\
\x0aQListView,\x0aQTre\
eView,\x0aQTableVie\
w,\x0aQColumnView {\
\x0a    background-\
color: #19232D;\x0a\
    border: 1px \
solid #32414B;\x0a \
   color: #F0F0F\
0;\x0a    gridline-\
color: #32414B;\x0a\
    border-radiu\
s: 4px;\x0a}\x0a\x0aQList\
View:disabled,\x0aQ\
TreeView:disable\
d,\x0aQTableView:di\
sabled,\x0aQColumnV\
iew:disabled {\x0a \
   background-co\
lor: #19232D;\x0a  \
  color: #787878\
;\x0a}\x0a\x0aQListView:s\
elected,\x0aQTreeVi\
ew:selected,\x0aQTa\
bleView:selected\
,\x0aQColumnView:se\
lected {\x0a    bac\
kground: #1464A0\
;\x0a    color: #32\
414B;\x0a}\x0a\x0aQListVi\
ew:hover,\x0aQTreeV\
iew::hover,\x0aQTab\
leView::hover,\x0aQ\
ColumnView::hove\
r {\x0a    backgrou\
nd-color: #19232\
D;\x0a    border: 1\
px solid #148CD2\
;\x0a}\x0a\x0aQListView::\
item:pressed,\x0aQT\
reeView::item:pr\
essed,\x0aQTableVie\
w::item:pressed,\
\x0aQColumnView::it\
em:pressed {\x0a   \
 background-colo\
r: #1464A0;\x0a}\x0a\x0aQ\
ListView::item:s\
elected:active,\x0a\
QTreeView::item:\
selected:active,\
\x0aQTableView::ite\
m:selected:activ\
e,\x0aQColumnView::\
item:selected:ac\
tive {\x0a    backg\
round-color: #14\
64A0;\x0a}\x0a\x0aQTableC\
ornerButton::sec\
tion {\x0a    backg\
round-color: #19\
232D;\x0a    border\
: 1px transparen\
t #32414B;\x0a    b\
order-radius: 0p\
x;\x0a}\x0a\x0a/* QHeader\
View -----------\
----------------\
----------------\
----------------\
- */\x0a\x0aQHeaderVie\
w {\x0a    backgrou\
nd-color: #32414\
B;\x0a    border: 0\
px transparent #\
32414B;\x0a    padd\
ing: 0px;\x0a    ma\
rgin: 0px;\x0a    b\
order-radius: 0p\
x;\x0a}\x0a\x0aQHeaderVie\
w:disabled {\x0a   \
 background-colo\
r: #32414B;\x0a    \
border: 1px tran\
sparent #32414B;\
\x0a    padding: 2p\
x;\x0a}\x0a\x0aQHeaderVie\
w::section {\x0a   \
 background-colo\
r: #32414B;\x0a    \
color: #F0F0F0;\x0a\
    padding: 2px\
;\x0a    border-rad\
ius: 0px;\x0a    te\
xt-align: left;\x0a\
}\x0a\x0aQHeaderView::\
section:checked \
{\x0a    color: #F0\
F0F0;\x0a    backgr\
ound-color: #146\
4A0;\x0a}\x0a\x0aQHeaderV\
iew::section:che\
cked:disabled {\x0a\
    color: #7878\
78;\x0a    backgrou\
nd-color: #14506\
E;\x0a}\x0a\x0aQHeaderVie\
w::section::hori\
zontal:disabled,\
\x0aQHeaderView::se\
ction::vertical:\
disabled {\x0a    c\
olor: #787878;\x0a}\
\x0a\x0aQHeaderView::s\
ection::vertical\
::first,\x0aQHeader\
View::section::v\
ertical::only-on\
e {\x0a    border-t\
op: 1px solid #3\
2414B;\x0a}\x0a\x0aQHeade\
rView::section::\
vertical {\x0a    b\
order-top: 1px s\
olid #19232D;\x0a}\x0a\
\x0aQHeaderView::se\
ction::horizonta\
l::first,\x0aQHeade\
rView::section::\
horizontal::only\
-one {\x0a    borde\
r-left: 1px soli\
d #32414B;\x0a}\x0a\x0aQH\
eaderView::secti\
on::horizontal {\
\x0a    border-left\
: 1px solid #192\
32D;\x0a}\x0a\x0a/* Those\
 settings (borde\
r/width/height/b\
ackground-color)\
 solve bug */\x0a/*\
 transparent arr\
ow background an\
d size */\x0a\x0aQHead\
erView::down-arr\
ow {\x0a    backgro\
und-color: #3241\
4B;\x0a    width: 1\
6px;\x0a    height:\
 16px;\x0a    borde\
r-right: 1px sol\
id #19232D;\x0a    \
image: url(:/qss\
_icons/rc/down_a\
rrow.png);\x0a}\x0a\x0aQH\
eaderView::up-ar\
row {\x0a    backgr\
ound-color: #324\
14B;\x0a    width: \
16px;\x0a    height\
: 16px;\x0a    bord\
er-right: 1px so\
lid #19232D;\x0a   \
 image: url(:/qs\
s_icons/rc/up_ar\
row.png);\x0a}\x0a\x0a/* \
QToolBox -------\
----------------\
----------------\
----------------\
------- */\x0a\x0aQToo\
lBox {\x0a    paddi\
ng: 0px;\x0a    bor\
der: 1px solid #\
32414B;\x0a}\x0a\x0aQTool\
Box::selected {\x0a\
    padding: 0px\
;\x0a    border: 2p\
x solid #1464A0;\
\x0a}\x0a\x0aQToolBox::ta\
b {\x0a    backgrou\
nd-color: #19232\
D;\x0a    border: 1\
px solid #32414B\
;\x0a    color: #F0\
F0F0;\x0a    border\
-top-left-radius\
: 4px;\x0a    borde\
r-top-right-radi\
us: 4px;\x0a}\x0a\x0aQToo\
lBox::tab:disabl\
ed {\x0a    color: \
#787878;\x0a}\x0a\x0aQToo\
lBox::tab:select\
ed {\x0a    backgro\
und-color: #505F\
69;\x0a    border-b\
ottom: 2px solid\
 #1464A0;\x0a}\x0a\x0aQTo\
olBox::tab:!sele\
cted {\x0a    backg\
round-color: #32\
414B;\x0a    border\
-bottom: 2px sol\
id #32414B;\x0a}\x0a\x0aQ\
ToolBox::tab:sel\
ected:disabled {\
\x0a    background-\
color: #32414B;\x0a\
    border-botto\
m: 2px solid #14\
506E;\x0a}\x0a\x0aQToolBo\
x::tab:!selected\
:disabled {\x0a    \
background-color\
: #19232D;\x0a}\x0a\x0aQT\
oolBox::tab:hove\
r {\x0a    border-c\
olor: #148CD2;\x0a \
   border-bottom\
: 2px solid #148\
CD2;\x0a}\x0a\x0aQToolBox\
 QScrollArea QWi\
dget QWidget {\x0a \
   padding: 0px;\
\x0a    background-\
color: #19232D;\x0a\
}\x0a\x0a/* QFrame ---\
----------------\
----------------\
----------------\
-------------- *\
/\x0a\x0aQFrame {\x0a    \
border-radius: 4\
px;\x0a    border: \
1px solid #32414\
B;\x0a}\x0a\x0aQFrame[fra\
meShape=\x220\x22] {\x0a \
   border-radius\
: 4px;\x0a    borde\
r: 1px transpare\
nt #32414B;\x0a}\x0a\x0aQ\
Frame[height=\x223\x22\
],\x0aQFrame[width=\
\x223\x22] {\x0a    backg\
round-color: #19\
232D;\x0a}\x0a\x0a/* QSpl\
itter ----------\
----------------\
----------------\
----------------\
---- */\x0a\x0aQSplitt\
er {\x0a    backgro\
und-color: #3241\
4B;\x0a    spacing:\
 0;\x0a    padding:\
 0;\x0a    margin: \
0;\x0a}\x0a\x0aQSplitter:\
:separator {\x0a   \
 background-colo\
r: #32414B;\x0a    \
border: 0 solid \
#19232D;\x0a    spa\
cing: 0;\x0a    pad\
ding: 1px;\x0a    m\
argin: 0;\x0a}\x0a\x0aQSp\
litter::separato\
r:hover {\x0a    ba\
ckground-color: \
#787878;\x0a}\x0a\x0aQSpl\
itter::separator\
:horizontal {\x0a  \
  width: 5px;\x0a  \
  image: url(:/q\
ss_icons/rc/Vsep\
artoolbar.png);\x0a\
}\x0a\x0aQSplitter::se\
parator:vertical\
 {\x0a    height: 5\
px;\x0a    image: u\
rl(:/qss_icons/r\
c/Hsepartoolbar.\
png);\x0a}\x0a\x0a\x0a/* QDa\
teEdit----------\
----------------\
----------------\
----------------\
---- */\x0a\x0aQDateEd\
it {\x0a    selecti\
on-background-co\
lor: #1464A0;\x0a  \
  border-style: \
solid;\x0a    borde\
r: 1px solid #32\
414B;\x0a    border\
-radius: 4px;\x0a  \
  padding-top: 2\
px;     /* This \
fix  #103, #111*\
/\x0a    padding-bo\
ttom: 2px;  /* T\
his fix  #103, #\
111*/\x0a    paddin\
g-left: 4px;\x0a   \
 padding-right: \
4px;\x0a    min-wid\
th: 10px;\x0a}\x0a\x0aQDa\
teEdit:on {\x0a    \
selection-backgr\
ound-color: #146\
4A0;\x0a}\x0a\x0aQDateEdi\
t::drop-down {\x0a \
   subcontrol-or\
igin: padding;\x0a \
   subcontrol-po\
sition: top righ\
t;\x0a    width: 20\
px;\x0a    border-t\
op-right-radius:\
 3px;\x0a    border\
-bottom-right-ra\
dius: 3px;\x0a}\x0a\x0aQD\
ateEdit::down-ar\
row {\x0a    image:\
 url(:/qss_icons\
/rc/down_arrow_d\
isabled.png);\x0a}\x0a\
\x0aQDateEdit::down\
-arrow:on,\x0aQDate\
Edit::down-arrow\
:hover,\x0aQDateEdi\
t::down-arrow:fo\
cus {\x0a    image:\
 url(:/qss_icons\
/rc/down_arrow.p\
ng);\x0a}\x0a\x0aQDateEdi\
t QAbstractItemV\
iew {\x0a    backgr\
ound-color: #192\
32D;\x0a    border-\
radius: 4px;\x0a   \
 border: 1px sol\
id #32414B;\x0a    \
selection-backgr\
ound-color: #146\
4A0;\x0a}\x0a\x0aQAbstrac\
tView:hover{\x0a   \
 border: 1px sol\
id #148CD2;\x0a    \
color: #F0F0F0;\x0a\
}\x0a\x0aQAbstractView\
:selected {\x0a    \
background: #146\
4A0;\x0a    color: \
#32414B;\x0a}\x0a\x0a\x0aPlo\
tWidget {\x0a    pa\
dding: 0px; /* t\
o fix cut labels\
 in plots #134 *\
/\x0a}\x0a\
\x00\x00\x02\xe1\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00 \x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\
\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\
\x01\x00\x9a\x9c\x18\x00\x00\x02\x93IDATX\x85\xed\
\x96?O\x14Q\x14\xc5\x7fgB\x18\xb6\xb5R>\x80\
\xc56J%\x95vR\x80b\xe8\xb4\xd3D\x8a\xad\xa4\
\x9a\x19 fL\xc4\x99\xa5\xa1\x92hL\xb4\xd3\x0e\xff\
\x00\x85Zi\xa5\x95n!\x89_\x00\xadl\x97\xd9\x98\
w-\xf6\x0d\xac\x09\xbb\xb8\x806\xee\xe9\xde\xbc\xfb\xde\
=\xf7\xce}\xe7^\x18`\x80\xff\x1d\xea\xc78M\xd3\
\xa1\xa2(\xa6\xccl\x068\x07\x8c\xfa\xadm\xe0\xa3\xa4\
\xb50\x0c7\xd24\xfdy\xec\x04\xe28\xbe\x08\xac\x00\
U\xe0\x13\xf0\x1e\xf8\xe6\xb7O\x01\xe7\x811`\xcb9\
wkyy\xf9\xedq\x11P\x14E\x89\xa4%\xe0\xb9\
\xa4\xc5,\xcb\xb6\xf63L\x92\xa4jfw\x81+\xc0\
B\x9e\xe79`G\x22\x10E\xd1\xbc\xa4;\x92jY\
\x96=\xfa\x03\xc2$Ir\xd3\xccV\x81\xdby\x9eg\
\x87&\xe0\xd3\xfeZ\xd2l\x87s\xc5q|\x0d\xa8\x01\
g\xfc\xb7\x06\xb0\x9a\xe7\xf9S|\xc4q\x1c\xcf\x02\x0f\
\x81\x89<\xcf\xdf\xf4M M\xd3\xa1\x9d\x9d\x9d\x06\xf0\
5\xcf\xf3\x19\x80\xb9\xb9\xb9\x13a\x18>\x01.\x03\x0e\
\x08\xbc\xb9\x03\x023{\xd9j\xb5n\xac\xac\xac\xfc\x00\
\x88\xa2\xe8\xb9\xa4\xd3###g\xba\x15f\xb0\xdfG\
\x80\xa2(\xa6\x80\xaa\xa4\xc5\x92\xacw>\xb5\xcf\xd9\x00\
@\xd2\xa5\xe1\xe1\xe1\xc7e`A\x10,\x00\xd5f\xb3\
9\xd9\xcdOW\x02\xfe\xa9}*\x0b\xce\xa7\xfdr\xaf\
3@ i:\x8a\xa2\xab\x00Y\x96m\x99\xd9gI\
3}\x13\xa0\xfd\xce\xdfw\xack\xb4S}\x10\x9c\xa4\
Z\xb9\x90\xf4\x0e\x18?\x0c\x81Q\xf6\xde9\xb4\x0b\xae\
\x97\xfd\xee\x9d\x92\xca\xe2\xc4\xcc\xbe\xb3'X}\x11\xf8\
'\xe8E`\x9b\xb6\xc2\x95h\xf0\x87\xbf\xc0\xcc\x1a\xe5\
B\xd2I\x7fW\xdf\x04>\xd2\x96\xd7\x12\xab\x07\xd8\xef\
\xde\xe9E\x08\x003\xbb\x00|\xe8\x9b\x80\xa45`,\
I\x92*\x80\x17\x99W\xf4\xce\x823\xb3\x97\xf5z\xfd\
\x19\xb4\xa5Y\xd2Y3[\xeb\x9b@\x18\x86\x1b\xc0\x96\
\xd7v\x00+\x8a\xe2\xba\x99\xad\x97\xce:\x1d\x03\x98\xd9\
z\xab\xd5\xba\x81WC\xe7\xdc\x12\xf0\xa5R\xa9lv\
\x0d\xb4G4]\xa58\x8a\xa2\xab\x92je\xb5\x9bY\
\xc3\xccV}\xe4\x9dR\xfc\xc097\xd1\xab3\xfe\x95\
f\xe4\x9d\xdf\xe7\xa8\xcd\xa8\xb4\x89\xe38\x06\xee\x99\xd9\
\x8b \x08\x16z\xb5c\xe7\xdc\x92\xa4i3\x9b\xaf\xd7\
\xebu\x8e\xda\x8eKt\x0e$^^\xdfy\x91A\xd2\
I3\xbb \xe9,\xf0\xc597w\x9c\x03\xc9.\xd2\
4\x1dj6\x9b\x93^\xdb\xc7\xf9}$\xfb`fk\
\x95Je\xb3\x9f\x91l\x80\x01\x06\xf8\x05h\xaf$(\
\x9ck\x07\xff\x00\x00\x00\x00IEND\xaeB`\x82\
\
\x00\x00\x00\xc3\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00@\x00\x00\x00@\x08\x06\x00\x00\x00\xaaiq\xde\
\x00\x00\x00\x06bKGD\x00\xff\x00\xff\x00\xff\xa0\xbd\
\xa7\x93\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\
\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\
\xdc\x0b\x07\x09.7\xffD\xe8\xf0\x00\x00\x00\x1diT\
XtComment\x00\x00\x00\x00\x00Cr\
eated with GIMPd\
.e\x07\x00\x00\x00'IDATx\xda\xed\xc1\x01\
\x0d\x00\x00\x00\xc2\xa0\xf7Om\x0e7\xa0\x00\x00\x00\x00\
\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x80w\x03@@\
\x00\x01\xafz\x0e\xe8\x00\x00\x00\x00IEND\xaeB\
`\x82\
\x00\x00\x00\x93\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00\x06\x00\x00\x00\x09\x08\x04\x00\x00\x00\xbb\x93\x95\x16\
\x00\x00\x00\x02bKGD\x00\xd3\xb5W\xa0\x5c\x00\x00\
\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\
\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x0b\x07\x0c\
\x0c+J<0t\x00\x00\x00$IDAT\x08\xd7\
c`@\x05\xff\xff\xc3XL\xc8\x5c&dY&d\
\xc5p\x0e##\x9c\xc3\xc8\x88a\x1a\x0a\x00\x00\x9e\x14\
\x0a\x05+\xca\xe5u\x00\x00\x00\x00IEND\xaeB\
`\x82\
\x00\x00\x01\x8a\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00 \x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\
\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\
\x01\x00\x9a\x9c\x18\x00\x00\x01<IDATX\x85\xed\
\xd71N\xc2P\x1c\xc7\xf1\xef\x9f&0Z\xa2\x963\
t\x11'N`\x02w\xe0\x14\x18\xbb\xa9\x83\x8c4\xe0\
%8\x831\xf1\x04\x9d\x00\x87\x9e\x01bB\x1d!i\
\xff\x0e\x94\x86\xb4\xe0\xa0m\x1c|\xbf\xf1\xf5\xa5\xbfO\
\xde[\xfe\x0f\xfe{$\xbf\xe0\xf8\xb3\xaeJ\xedV\x95\
\x0e`\x97\xd4\x13\x89\x10\x88&\xe3\xd5\xdd\xf5\xebI\xc0\
\xb9\xbf\x18\x0a\xdc\x03\x1b\xd0\x10\x95\xcfR\xeaE\xcf@\
\x5c\xa0\x812\xfc\xf0\xae\x1e\x0b\x80\xcb\xf1\xbc\xa7\x89\xbc\
\x00o\x96j\x7f\xe9\xb5W\xa5\x94\xa7i\x8d\xe6N,\
2\x05nj$\xbd\xfdI\xd4\xb2\x1d*\x03`SE\
9\xc0\xd2k\xaf,\xd5>\xb0\x8d\xb1\x06\xfb\xf5\x0c\xb0\
\xbbs\x0d\xab(?D\x00\xa1\xa0\x9d\x02\x00\xb0K\xbb\
\xf3\xef\xa2D@\xf3\x18\xe0Ob\x00\x06`\x00\x06`\
\x00\x06`\x00\x06p\x08\x88v\xd3k\xc5\x11l`]\
\x00\x88\x10\x80\xb8\xad\xd1\xdc\xa9\xaa;\xfd\xb7\xabHP\
\x04h2\x06\x1a\xb1\xc8\xb4\x0a\x84\xf3\xfc\xdeJ\xc7\xf2\
\xbaE<\xc9z\x0f7]\x8c\x16O\x08\x0f\xc0\x16\x08\
\xd3\x01\xf2\xf7\xd9\x1d\xbb\x0b\xd4O>L2\xa9?\xeb\
\xc6X\x83ttn\xe6\xbf\xff0kE\x02\x8bx\x92\
\x7f\x9a\x99|\x01\x0b\xfao8\x11\xee\x15\x0b\x00\x00\x00\
\x00IEND\xaeB`\x82\
\x00\x00\x01\x82\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00 \x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\
\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\
\x01\x00\x9a\x9c\x18\x00\x00\x014IDATX\x85\xed\
\xd7\xb1N\xc2P\x18\x86\xe1\xf77\x14F\xca\x82\xd7\xd0\
\x85DH\xea\x0a\xd1T\x22\xc6\x1b\xe0*\xea,\x0e\xb2\
\xc3Up\x09\xc4\xd8\x98\xb0w\xd0\x84\xa5\xf7\xc0B\x1d\
\xb1$\xc7\xa1-6\xb58\x986\x0e\x9eo<m\xfa\
=\xe7t\xf9\x0f\xfc\xf7H~\xa1;\x18]\x81\xba\x03\
\xb1\x01\xb3\xa4\x9e\x10\x94\x0f2{]-\x9f\x8f\x02z\
\xfd\x9b\xa9\x12u\x0f\xec\x04\x02\x85z/\xa3]\x90\xa6\
\x02\x0bh(\x98\xbe\xad\x96\x0f\xdf\x00\xdd\xfe\xf5\x10\x91\
'\xe0eoD\xe3\xb5\xe7m\xca(O\xd3q\x9cv\
-2\x16\xc0%0LO\xe2$\xc3t\x81]\x15\xe5\
\x00k\xcf\xdb\xec\x8dh\x0c|\x00n\xba\xfe\x05@l\
\x81\xa0\x8a\xf2,\x02\x08\x00\xbb\x00\x80Y\xd6?\xff9\
*\x04ZE\x80?\x89\x06h\x80\x06h\x80\x06h\x80\
\x06h@\x16\x10\x0a\xd2\xac\xbeRL`[\x00P\xbe\
\x02\xab\xe38\xed\xaa\xaa\x93o[\x80_\x00\x90\x19\xd0\
\xa8E\xc6\xa2\x0a\xc4\xf9\xc5\xedi2\x96\xd7\x81\xf9\xa1\
5\xfb\xd2\xd9`\xf4(0!\x1e\x9d\x83d\x80,!\
b\x12\xef\xbc~\xf4b\x92&\xbe\x9a\xe1\x12\x8f\xce\xad\
\xfc\xf3_fK|\xec\xf3\xfc\xd5L\xe7\x13\xc4\xb0_\
D\xcf\x0c[\xaa\x00\x00\x00\x00IEND\xaeB`\
\x82\
\x00\x00\x025\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00@\x00\x00\x00@\x08\x06\x00\x00\x00\xaaiq\xde\
\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\
\x00\x00\x01\xecIDATx\x9c\xed\x9b\xdd\x91\xc3 \
\x10\x837W\xc3\xd5\x91\xeaR\xc6Uwu\xa4\x87\xe4\
\x89\x19\x86\xb1aa%\x81\xc7\xe8\xd9\x11\xd6\xc7\x8f\xbd\
\x04\x9bmmm\xddY\x0fec\xbf\x7f\xff\x1f\xcfu\
\xef\xd7Sv_\xd4\x86\xbc\x81[b\x02\x81\x1b\xa3B\
\x9f\x09\x0d\x03f\xc6\x0e^\x0a\x05\x02b\xa2\x0e\x9f\x84\
\x80\x102\x98\x15\xbcT\x04\xc4\xf0\x0fW\x09\x9f4\x0a\
\xa1\xfbG\xab\x05/\xd5\x0b\xa2\xeb\xe2\xd5\xc3'\xf5@\
p_x\x95\xf0I^\x08?\xec\x1bY].JW\
\xeb\xfd$\xcf(h^\xd0\x0a\x9f7\xa2\x02U\x06\xab\
\xb5\xdb\x82\x00\x9d\x02\xef\xd7\xf3\xc1.d\xd0\xfeU\x00\
\xa3=\xca\x820\xe2\xdb\xcap\x0a :\x9c\xd1\x10\x22\
~\xb5,\xe1)\x10\x99\x7f^\xd5|\xa2\x1duh<\
b\xca\xbaI\xa4\xef\x91\x17l\x11d\x8c\x04f\xcf'\
A\x9f\x02H\x08\x8a\xf0f\x07S\x00a\x1e\xbdyf\
\xf8\xd2\x9b\xf2*\x1c\x19\x09\xaa\x9eO\xa2\xd5\x02#\x10\
\xd4\xe1\xcd\xc8\xc5P\x0f\x84\x19\xe1\xcd\x8a5\x80\xd5P\
+\x9c:|\xde\x9e\xa4\x1c\x1e]\x13\x14\xc5\x95l?\
\xa07\x8c\xaa\xb2\x94n\x88xC)\xf7\x1f\xe4;B\
\xadp\xea\xcd\x179\x80\xc8{\x00CR\x00\xdepJ\
\x082\x00\xc8Z\x00)\x09\x80\xd1G\x9d\x02\x02\x1d\x80\
'\xfcL\x08\x94j0\xa9\xb7\xe7\x15/E\x92j\xf0\
\xa8\xa1\x5cgaf\x8c\x04\x0a\x80HO\xaa!\xc0\x01\
 \x86\xb1\x12\x02lS\xd4\x0c?\x87\x15~\xb0\x11\xc0\
X\xc0\x14#\x01\x02\x80\xb9z\xb3!\x84o\x5cU\xcf\
\xb36Z\xa7\xec\x09\xae\xe0\x97t\x0a\x80\xf5_\x5cD\
\x8c\xc5\x19>\x02\xd8\xf5<\xda?|@bu\xb5F\
\xf2>\x22\xe35\xbb\x1a\x84}J\xcc\xa9}P\xb2\xd7\
|u\x08\xd4\xa3\xb2\xb9V\x03!;,\x9dk\x15\x08\
S\x8e\xcb'\xcd\x86\x10-\x88\xf6'3\x08\x93\x5c\xb7\
\xfdh\xeaH\xb7\xfcl\xae\xa6\x15?\x9c\xdc\xba\xbb\xbe\
\x18_Z\xd7\x14T\xdf\xfe\x00\x00\x00\x00IEND\
\xaeB`\x82\
\x00\x00\x00\xef\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00Q\x00\x00\x00:\x08\x06\x00\x00\x00\xc8\xbc\xb5\xaf\
\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\
\x06bKGD\x00\xff\x00\xff\x00\xff\xa0\xbd\xa7\x93\x00\
\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\
\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x08\x17\
\x0b*2\xff\x7f Z\x00\x00\x00oIDATx\
\xda\xed\xd0\xb1\x0d\x000\x08\x03A\xc8\xa0\x0c\xc7\xa2I\
\xcf\x04(\xba/]Y\x97\xb1\xb4\xee\xbes\xab\xaa\xdc\
\xf8\xf5\x84 B\x84(\x88\x10!B\x14D\x88\x10!\
\x0a\x22D\x88\x10\x05\x11\x22D\x88\x82\x08\x11\x22DA\
\x84\x08Q\x10!B\x84(\x88\x10!B\x14D\x88\x10\
!\x0a\x22D\x88\x10\x05\x11\x22D\x88\x82\x08\x11\x22D\
A\x84\x08Q\x10!B\xfc\xaa\x07\x12U\x04tV\x9e\
\x9eT\x00\x00\x00\x00IEND\xaeB`\x82\
\x00\x00\x00\xb6\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00\x18\x00\x00\x00\x11\x08\x06\x00\x00\x00\xc7xl0\
\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\
\x06bKGD\x00\xff\x00\xff\x00\xff\xa0\xbd\xa7\x93\x00\
\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\
\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x08\x17\
\x0b,\x0d\x1fC\xaa\xe1\x00\x00\x006IDAT8\
\xcbc` \x01,Z\xb4\xe8\xff\xa2E\x8b\xfe\x93\xa2\
\x87\x89\x81\xc6`\xd4\x82\x11`\x01#\xa9\xc9t\xd0\xf9\
\x80\x85\x1cMqqq\x8c\xa3\xa9h\xd4\x82ad\x01\
\x001\xb5\x09\xec\x1fK\xb4\x15\x00\x00\x00\x00IEN\
D\xaeB`\x82\
\x00\x00\x00\x81\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00\x10\x00\x00\x00\x10\x01\x03\x00\x00\x00%=m\x22\
\x00\x00\x00\x06PLTE\x00\x00\x00\xae\xae\xaewk\
\xd6-\x00\x00\x00\x01tRNS\x00@\xe6\xd8f\x00\
\x00\x00)IDATx^\x05\xc0\xb1\x0d\x00 \x08\
\x04\xc0\xc3X\xd8\xfe\x0a\xcc\xc2p\x8cm(\x0e\x97G\
h\x86Uq\xda\x1do%\xba\xcd\xd8\xfd5\x0a\x04\x1b\
\xd6\xd9\x1a\x92\x00\x00\x00\x00IEND\xaeB`\x82\
\
\x00\x00\x02)\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00@\x00\x00\x00@\x08\x06\x00\x00\x00\xaaiq\xde\
\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\
\x00\x00\x01\xe0IDATx\x9c\xed[Ir\xc0 \
\x0cs;}t\x9e\x90_\xb7'fh\x86\x04\x03\x92\
\xec6\xe8L\xbc(b7f\x1b\x1b\x1bo\xc6\x87\xd2\
\xd9q\x1c\xdf\x9ev\xe7y\xca\xe2\xa2:\xf2&\xdc\x03\
\x93\x10\xb8aT\xd2w@\x93\x013\xc6N\xfc\x0a\x14\
\x11\x10#\xea\xe4\x0b\x10$,\x19\x88J\xfc\x8a\x15\x22\
\xa6?\xcc\x92|\xc1,\x09\xc3\x1feK\xfc\x8aQ\x22\
\x86\x1agO\xbe`\x84\x04w\xc3\xbf\x92|\x81\x97\x84\
/v O\xa8\x83\x8c\x22\xd8\xc5\x12#\xb8\xd6\x1fB\
\xfb\xf1\xa8\xa0\xdb@\x95<\xcb_\x8f\x84O\xa43\x0f\
z\x01)7Bf\x1d\x05DH\x92\xe1\xfb\xc9o\x1a\
)\xb2c\xb8\xf3/\xe9\x02\xb3}^\xd1\x1d\x9a\x0eT\
\xf2\xab\xfd(\x06\xc6\x96\x0f\xaa\x02F\x92\x8aR\x02\x8d\
\x80\x99?\x1aA\x02e1\xb2*gfw\xb8\xda\x86\
+\x00\x11\xbcR\x09P\x02\x90\x7fNE\x02\x8c\x00\x86\
l\x15$\xfc22\x1b({\x0aC\xdb\xaf\xed-+\
@1\x7f3\x95\xb0D\x80rW\xc7\x22a\x9a\x00e\
\xf2\x1e\xbb\xb3$\xc0\xa7A\xf6\xc9\x0e\xda\xbet\x1d\x90\
\xd1\xfe4\x01\x11\xcbVF\xb7[R\x80\x92\x04\xd6\x98\
\xb3\xdc\x05\x14$0\x07\x5c\xc8\x18\xc0$\x81=\xdb@\
w\x83\xcc\x15\x1b\xc2^\xcb&t\x16@*A\xb5\xce\
\x90\xae\x03\xbc$(\x17Y\x94\x13\xa1\x15\x12\xd4+L\
\xea\xa1\xe8h2\x11\xbbJ\xea\xa1\xe8\x88\x12\x22\xf6\x16\
f\x82{\x01\x0f\x09Q\xc9\x9b\xed\x9b!\xdd\xe5(\xf2\
L\x10\x09\xe9\xe5\xa8\x99O\x09J\xf5\xc9\xaf\xc7{\xc9\
\xa9+EB\x0a$\xcc4\x15\x22w~j\x84\x95\xc8\
\x98\xf1k\x84 %2\x05\xff\xb5JL>\x06d\xc3\
.\x94\x1c5\x9e\x9d\x04j\xa9l\x8dlD\xc8\x8a\xa5\
kd!!\xa4\x5c\xbe \x9a\x84\xd53\xc7\xfdd\x06\
a\xa4\xc6k\x1fM\xb5\xf0\xcagsO\xc8\xf8pr\
\xe3\xed\xf8\x01\xedrr\xcc\x11N\x0c\xe5\x00\x00\x00\x00\
IEND\xaeB`\x82\
\x00\x00\x00\xac\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00\x07\x00\x00\x00?\x08\x06\x00\x00\x00,{\xd2\x13\
\x00\x00\x00\x06bKGD\x00\xb3\x00y\x00y\xdc\xdd\
S\xfc\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\
\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\
\xdf\x04\x19\x10.\x14\xfa\xd6\xc4\xae\x00\x00\x009ID\
AT8\xcbc` \x06\xc4\xc7\xc73\xc4\xc7\xc7\xa3\
\x881aS\x84S\x12\xaf\xce\x91(\xc9\x82\xc4\xfe\x8f\
\xc4f\x1c\x0d\xa1Q\xc9Q\xc9QI|\x05\x06\xe3h\
\x08\x91*I>\x00\x00\x88K\x04\xd39.\x90?\x00\
\x00\x00\x00IEND\xaeB`\x82\
\x00\x00\x025\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00@\x00\x00\x00@\x08\x06\x00\x00\x00\xaaiq\xde\
\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\
\x00\x00\x01\xecIDATx\x9c\xed\x9bK\x92\xc3 \
\x10C\xc9\x9ca\x0e\x98\xc5\x1c+\x8b9`\xee\x90\xac\
\xa8\xa2(\x1b\x1aZ\x12\xed2Z;\xc2z|\xec&\
8\xa5\xad\xad\xad;\xeb\xa1l\xec\xf7\xef\xffc\xb9\xee\
\xfdz\xca\xee\x8b\xda\x905pOL pcT\xe8\
3\xa1a\xc0\xcc\xd8\xc1k\xa1@@L\xd4\xe1\xb3\x10\
\x10\x5c\x06\xab\x82\xd7\xf2\x80\x98\xfea\x94\xf0Y\xb3\x10\
\x86\x7f\x14-x\xadQ\x10C\x17G\x0f\x9f5\x02\xc1\
|\xe1U\xc2gY!\xfc\xb0o$\xbaL\x94\xae\xd6\
\xfbY\x96Q\xd0\xbd\xa0\x17\xbelD\x05\xaa\x0e\xd6j\
\xb7\x07\x01:\x05\xde\xaf\xe7\x83]\xc8\xa0\xfd\x9b\x00f\
{\x94\x05a\xc6\xb7\x97\xe1\x14\x80w8\xa3!x\xfc\
ZY\xdcS\xc03\xff\xacj\xf9x;\xea\xd0x\xc6\
\x94u\x93H\xdf#/\xd8\x22\xc8\x18\x09\xcc\x9e\xcf\x82\
>\x05\x90\x10\x14\xe1S:\x98\x02\x08s\xef\xcd3\xc3\
\xd7\xde\x94Wa\xcfHP\xf5|\x16\xad\x16\x98\x81\xa0\
\x0e\x9f\x12\xb9\x18\x1a\x81\xb0\x22|J\xd5\x1a\xc0j\xa8\
\x17N\x1d\xbelOR\x0e\xcf\xae\x09\x8a\xe2J\xb6\x1f\
0\x1aFUYJ7D\xac\xa1\x94\xfb\x0f\xf2\x1d\xa1\
^8\xf5\xe6\x8b\x1c\x80\xe7=\x80!)\x00k8%\
\x04\x19\x00d-\x80\x94\x04\xc0\xec\xa3N\x01\x81\x0e\xc0\
\x12~%\x04J5\x985\xda\xf3\x8a\x97\x22I5x\
\xd4P\xa9\xb30+F\x02\x05\x80\xa7'\xd5\x10\xe0\x00\
\x10\xc3X\x09\x01\xb6)\x9a\x12~\x0e+\xfc`#\x80\
\xb1\x80)F\x02\x04\x00s\xf5fCp\xdf\xb8\xaa\x9e\
gm\xb4.\xd9\x13\x8c\xe0\x97u\x0a\x80\xf5_\x9cG\
\x8c\xc5\x19>\x02\xd8\xf5<\xda\xdf}@\x22\xbaz#\
y\x1f\x91\xb1\x9a]\x0d\xc2>%f\xd4>(9j\
\x1e\x1d\x02\xf5\xa8l\xa9h d\x87\xa5KE\x81\xb0\
\xe4\xb8|\xd6j\x08\xde\x82h\x7f2\x830)u\xdb\
\x8f\xa6\x8et\xcb\xcf\xe6Z\x8a\xf8\xe1\xe4\xd6\xdd\xf5\x05\
\x90\xc2Z}\xfa\xa7\x95\xa2\x00\x00\x00\x00IEND\
\xaeB`\x82\
\x00\x00\x0b\x1f\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00@\x00\x00\x00\x10\x08\x06\x00\x00\x00\xa6\xe7y)\
\x00\x00\x00\x87zTXtRaw prof\
ile type exif\x00\x00x\
\xdaU\x8e\xcb\x0d\xc3@\x08D\xefT\x91\x12\xf8\xed\xb0\
\x94\x13Y\xb6\x94\x0eR~@k\xcb\xf1;\xc0h\xb4\
\xfb\x04\xed\xdf\xcfA\xafFX\xc9GL$\xc0\x85\xa7\
\xa7\xbe+L^\x18\xb3(K\xef\x9a\x8bs\x9bT\xd2\
\xbb&\xd3\x15\x903\xd8\xef\x87~\xf6\x17\xc30q\x84\
G``\xc3\xa6e\xd7\xdd\xd4\xb4f\x8b\xda\xca}F\
\xfeI\xae\xdf\xf6\xec\xe5\xe9f\xfa\x01?{,\x10\xd8\
2\x95\xc4\x00\x00\x0a\x02iTXtXML:c\
om.adobe.xmp\x00\x00\x00\x00\
\x00<?xpacket begin\
=\x22\xef\xbb\xbf\x22 id=\x22W5M0M\
pCehiHzreSzNTczk\
c9d\x22?>\x0a<x:xmpmet\
a xmlns:x=\x22adobe\
:ns:meta/\x22 x:xmp\
tk=\x22XMP Core 4.4\
.0-Exiv2\x22>\x0a <rdf\
:RDF xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22>\x0a  \
<rdf:Description\
 rdf:about=\x22\x22\x0a  \
  xmlns:exif=\x22ht\
tp://ns.adobe.co\
m/exif/1.0/\x22\x0a   \
 xmlns:tiff=\x22htt\
p://ns.adobe.com\
/tiff/1.0/\x22\x0a   e\
xif:PixelXDimens\
ion=\x2264\x22\x0a   exif\
:PixelYDimension\
=\x2216\x22\x0a   tiff:Im\
ageWidth=\x2264\x22\x0a  \
 tiff:ImageHeigh\
t=\x2216\x22\x0a   tiff:O\
rientation=\x221\x22/>\
\x0a </rdf:RDF>\x0a</x\
:xmpmeta>\x0a      \
                \
                \
                \
                \
                \
              \x0a \
                \
                \
                \
                \
                \
                \
   \x0a            \
                \
                \
                \
                \
                \
        \x0a       \
                \
                \
                \
                \
                \
             \x0a  \
                \
                \
                \
                \
                \
                \
  \x0a             \
                \
                \
                \
                \
                \
       \x0a        \
                \
                \
                \
                \
                \
            \x0a   \
                \
                \
                \
                \
                \
                \
 \x0a              \
                \
                \
                \
                \
                \
      \x0a         \
                \
                \
                \
                \
                \
           \x0a    \
                \
                \
                \
                \
                \
                \
\x0a               \
                \
                \
                \
                \
                \
     \x0a          \
                \
                \
                \
                \
                \
          \x0a     \
                \
                \
                \
                \
                \
               \x0a\
                \
                \
                \
                \
                \
                \
    \x0a           \
                \
                \
                \
                \
                \
         \x0a      \
                \
                \
                \
                \
                \
              \x0a \
                \
                \
                \
                \
                \
                \
   \x0a            \
                \
                \
                \
                \
                \
        \x0a       \
                \
                \
                \
                \
                \
             \x0a  \
                \
         \x0a<?xpac\
ket end=\x22w\x22?>'q\xef\
\x0e\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\
\x88\x00\x00\x005IDATX\xc3\xed\xd5\xb1\x0d\x00\
0\x08\x041\xc8\xa2\xcc\xc6\xa4I\x9b\x1d\xde\xee(\x91\
@WE\xb6\xfe\x87\x99\xb9I\xcb\xefn\x9f\xf4\x0b8\
\x9e\x00\x90A\x19\x94A\x80H\x0f\xc6\x9d\x08\x0b\xaac\
u(\x00\x00\x00\x00IEND\xaeB`\x82\
\x00\x00\x03\x0a\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00 \x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\
\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\
\x01\x00\x9a\x9c\x18\x00\x00\x02\xbcIDATX\x85\xed\
\x96\xbdO\x14Q\x14\xc5\x7fg\x86\xd0H,\x981Q\
\xff\x00\x8b\xd5\x15\xad\xb4\xd2\xd8h!~\x84N:M\
\xa4\xa0RY\x8d\x82\x05\x85\x1a\x95A;\xa21\xd1N\
;\x14\xc1B-\x08TZ\xe9\xee\xba$\xfe\x03h\xe2\
\x0e\x85\xc1\x06\xdcw-vF\x88\xb2\xcb.\xc1\xca=\
\xd5{3\xf7\xe3\xbc\xfb\xde;\xf7A\x0b-\xfc\xefP\
S\xd6\xc3\xd3mAG\xd0-\xac\x07t\x00\xd8\x99\xfc\
\x99\x07{oh<^\x8c\xa7\x18>\xf2s\xd3\x09t\
\xde-\x1e\xf5<\xbb\x0fd\x80\x0f\x86f1\xfbR\x8d\
\xa2\x1d\xc2\x0e\x01\xfb\x819\x87.,\xe4\xb2o7\x87\
\x80\x99\xb6\x8d\x16\xae\x19\xba)\xf1\xbcb\xfe\xf5\x85\xdc\
\xee\xb95IF\xa5\x8c\xaf\xca\x0d3N\x9bi(\xce\
\xed\xb9\x8dd\x8d.rMl\x8b\xf2\x83aTX\x0e\
G\x0a\xe7\x1b\xf5\x09G\x0a\xe7\xc3\xa8\xb0\x1c\x8c\x14\xaf\
\xadg[\xb7\x02I\xd9_c\xf4\x95/\xef}\x04\x80\
\x99\xc2\xd1b\xafA\xbf\xa0\x0b\xc0 /\x18+\x0fd\
\x9f\xa6+\x0e\xa3B\x1f\xf0\xd09\x1d[\xb8\x92}\xd3\
<\x81\xe1\xe9\xb6\xb0#\xc8K|\xfe6\xb0\xb7\x07`\
\xeb\xbdRg\xbbU\x9e`\x9c4\xc3IxUN\xc9\
XL,\xc9?\xf7\xfd\xd2\xee\x85\x84\xc4s`Wy\
1\xee\xaau0\xbdZ\xf9\x83\x8e\xa0\x1b\xc8T\xcc\xbf\
\x9e\xae\xbc\xdd*O\xcc\xe8\x06H\x93\xaf\x1e\x9bq\xa2\
\xdd*\x8f1\x13\x80\xc3\x1f\x022\xc1\x96\xe0x\xad<\
5\x09T\xaf\x1a\x1f\xd2\x03\x17\x8e\x16{1N\xaa\xae\
\x0f\x1e\xc6\xa90*\x9e\x01\xa8\xfa\xdaG\x0f\xf54M\
\x00t\xc0\xd0l:3\xe87\xc3\xd5\xb6O\xec\x0c\x87\
g\xfd+~\xde\x8c\xc9\x0e\xd6\xb2o\xab\x13k\xe7\xef\
{\x0e\x08\xbaP=\xc2\x89\x9d\xf0@]\xab(}e\
E\xb0\xfe\xc2\xba\x01\xff5\xea\x11\x98G\xda\x91N\x0c\
\xf2\x0do\x01\x96_\xf9\xa2\xed\xc0\xfc\x06\x08\xd8\xfbD\
^\xaba`L\x8dn\x81\xd3\xd8\x8a\x9f;,\xd3\xbb\
\xa6\x09\x18\x1a\x07\xf6wF\xa5\x0c@Udxi\xd4\
\xae\x82\x81CL\x94s\xd9gP\x95f\xd0>\x87\x8d\
7M ^\x8c\xa7\x809_\x95\x1b\xc9\xd2lI\xfe\
Y\x89IHK\x9d$N\xc6\x12\x93K\xf2\xcf\xa5j\
\xe8Q\xb9\x09\x94\xe2\x1f\xf1\xabZy6&\xc5Q\xf1\
L\xf5\xaa\xa5\xa7\xdd\xf28\x8d\x95s\xd9g\x7fH\xf1\
\x03\x87\x8e5\xda\x19\xd7\xc4\x86\x9aQT\xe8\xdb\x94f\
\x04\x80\x99\x82\xe8\xd3U\xc9n\x01/\x1c\xfeP\xbdv\
\x9c\x94\xfd\x94\xc1`<\x90\xbd\xb3^;\xde\xe0\x83\xc4\
>\x1a\xdeL\x222\x80\xb6\x0bw\x18\xb4\x0f(9t\
q\xf3\x1e$\xab1<\xdd\x16l\x09\x8e{\xa8'\x91\
\xd7\xdfO2\x99\xde9l<\xfe\x11\xbfj\xe6I\xd6\
B\x0b-\xfc\x02\x9d\x07<\xe4\x1f\x0b_\x15\x00\x00\x00\
\x00IEND\xaeB`\x82\
\x00\x00\x01\x9d\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00 \x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\
\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\
\x01\x00\x9a\x9c\x18\x00\x00\x01OIDATX\x85\xed\
\x97\xbfN\xc2P\x14\x87\xbfC(\x8c\x94\x05\x9f\x81\x85\
DLp\x85h*\x11\xe3\x0b\xf0\x14uV\x07\xd9\xe1\
)x\x04blL\xbaw\xc0\x84\xa5\xef\xc0\x02\x8eX\
\x92\xebP\x8aM\xf9\xd3DZ\x17\xef\xb7\xf5\xde\x9b\xfe\
\xbe\x9e\xa6\xe99\xf0\xdf\x91\xe4B\xb3\xd3\xbb\x01\xf5\x00\
\xd2\x02\xcc\x8cr\x96\xa0<\x90\xe1\xd4\x9d\xbc\x1d\x14\xb8\
h\xdf\x0d\x94\xa8G`%\xe0+\xd4g\x16\xe9\x82T\
\x14\xd4\x81\xb2\x82\xc1\x87;y\xde\x11h\xb6o\xbb\x88\
\xbc\x02\xefk#\xe8\xcf\x1cg\x9eExD\xc3\xb2j\
\xc5\xc0\x18\x03\xd7@7\xaaD!\xa6i\x03\xab<\xc2\
\x01f\x8e3_\x1bA\x1f\xf8\x02\xech\xfdG\x00i\
\x09\xf8y\x84\xc7%\x00\x1fh\xed\x11\xc0\xcc\xea\x9d\x1f\
G-\x81jtUL;\xde\xec\xf4\xd4)qSw\
\xb2\xf3\xa5\xc5)\x1c\xdb\xfc\x0b\xb4\x80\x16\xd0\x02Z@\
\x0bh\x01-\x90\xda\x0f\xa4\xfd\xcfO%^\x81\xa5 \
\x95<\xc3B\xc4\x04\x16{\x04\x94\xa7\xa0\xde\xb0\xacZ\
^\xd1\x9b{\xd7\x01o\x8f\x80\x0c\x81r10\xc6y\
H\x5c^\xdd\x9fm\xda\xf2\x120\xda\xa6\xc6\x0f\x9dw\
z/\x02O\x84\xad\xb3\xbfi 3@L\xc2'/\
\x1d\x1cL\x22\xc2\xd1\x0c\x9b\xb0u\xae&\xf7\x7f\xc9\x82\
\xb0\xec\xa3\xe4h\xa6\xf9\x06\xfe\xc1e\x8b\x9b\xf2\xc3\xc8\
\x00\x00\x00\x00IEND\xaeB`\x82\
\x00\x00\x01\xa2\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00 \x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\
\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\
\x01\x00\x9a\x9c\x18\x00\x00\x01TIDATX\x85\xed\
\x97Aj\xc2@\x14\x86\xbf\x17\x82.\x8d\x1b{\x06/\
\xe0\x09\x0az\x07Oa\x09d\x94\xb6\x8b\xba\x89\x10\xf4\
\x14\x9e\xa1\x14z\x02/\xe0\x1d\xdch\x97J\xc8\xdfE\
MI\x15+\xb4I7\xcd\xb7\x9b7\xc3\xfc\x1f\x19\xc2\
\xbc\x81\xff\x8e\x9d\x16\xa2(\xea\x9b\xd9\x9d\xa4\x9e\x99\x05\
e\x84H\xda\x99\xd9J\xd2|6\x9b\xbd\x5c\x14\x18\x8f\
\xc7SI\xf7\xc0^\xd2\xda\xcc\xdeJ\x12h\x99Y\x17\
h\x02\xd38\x8e\x1f\xcf\x04\x9cs\x03\xe0\x19xM\xd3\
t\x98$\xc9\xa6\x8c\xf0\x9c0\x0c;\xbe\xef/\x81[\
I\x83\xfcKx\x855#`_E8@\x92$\x9b\
4M\x87\xc0\xc1\xf3\xbcQ^\xff\x14\x90\xd4\x93\xb4\xae\
\x22\xbc(\x01\xac%\xf5\xce\x04\xcc,(\xeb\xcc\xaf\xb0\
\x03\xda\xf9\xc0\xbf\xb6\xda9\xa7\xdf\xa4\xc5q|\xf6\xa7\
\x15\xf1\xbe\x9b\xfc\x0bj\x81Z\xa0\x16\xa8\x05j\x81Z\
\xa0\x16\xb8\xda\x0f\x5c\xbb\xcfK\x13\x90\xb4\x03ZU\x86\
\x1d\x09\x80m>(\xb6d+3\xeb\x86a\xd8\xa9*\
\xf9\xb8w\xd7\xccVg\x02\x92\xe6@\xd3\xf7\xfde\x15\
\x12\x93\xc9\xe4\xe6\xd8\x967\xb2,[\xe4\xf5/\xe7\xeb\
\x9c{\x02\x1e\x80\x03\xb0\xe6\xa3\x81,\x83\x00\xe8\x02\x0d\
.=Lr\xa2(\xea{\x9e7:\xb6\xce\xed\xd3\xf9\
\x1f\xb25\xb3U\x96e\x8b\xd3\xa7Y\xcd;\xf1#\x82\
\xe5\xfbO\xe3\xdb\x00\x00\x00\x00IEND\xaeB`\
\x82\
\x00\x00\x00\xa0\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00\x06\x00\x00\x00\x09\x08\x04\x00\x00\x00\xbb\x93\x95\x16\
\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\
\x02bKGD\x00\xff\x87\x8f\xcc\xbf\x00\x00\x00\x09p\
HYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\
\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x14\x1c\x1f$\
\xc6\x09\x17\x00\x00\x00$IDAT\x08\xd7c`@\
\x05\xff\xcf\xc3XL\xc8\x5c&dY&d\xc5p\x0e\
\xa3!\x9c\xc3h\x88a\x1a\x0a\x00\x00m\x84\x09u7\
\x9e\xd9#\x00\x00\x00\x00IEND\xaeB`\x82\
\x00\x00\x00\xe0\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00Q\x00\x00\x00:\x08\x06\x00\x00\x00\xc8\xbc\xb5\xaf\
\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\
\x06bKGD\x00\xff\x00\xff\x00\xff\xa0\xbd\xa7\x93\x00\
\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\
\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x08\x17\
\x0b)\x1c\x08\x84~V\x00\x00\x00`IDATx\
\xda\xed\xd9\xb1\x0d\x00 \x08\x00AqP\x86cQ\xed\
\x8d\x85%\x89w\xa5\x15\xf9HE\x8c\xa6\xaaj\x9do\
\x99\x19\x1dg\x9d\x03\x11E\x14\x11\x11E\x14QDD\
\x14QD\x11\x11QD\x11EDD\x11E\x14\x11\x11\
E\x14\xf1[\xd1u\xb0\xdb\xdd\xd9O\xb4\xce\x88(\x22\
\x00\x00\x00\x00\x00\x00\x00\x00\x00\xcf6\xcei\x07\x1e\xe9\
9U@\x00\x00\x00\x00IEND\xaeB`\x82\
\x00\x00\x01\xa8\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00 \x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\
\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\
\x01\x00\x9a\x9c\x18\x00\x00\x01ZIDATX\x85\xed\
\x97Mj\xc2P\x14\x85\xbf\x1b\x82\x0e\xab\x13\xbb\x067\
\xe0\x0a\x0a\xba\x07Wa\x09\xe4)m\x07u\x12!\xe8\
*\x5cC)t\x05\xd9\x80{p\xa2\x1d*!\xa7\x83\
\x1a\xb1\x86P(\xb1\x16\x9a3{\xf7>\xde\xf9\xb8\xef\
\x87\xfb\xe0\xbf\xcb\xce\x03a\x18\xf6\xcd\xec^R\xcf\xcc\
ZU\x98H\xda\x9aY\x22i>\x9b\xcd^K\x01\xc6\
\xe3\xf1T\xd2\x03\xb0\x93\xb42\xb3\xf7\x8a\x00n\xcc\xac\
\x0b4\x81i\x14EO\x05\x00\xe7\xdc\x00x\x01\xde\xd2\
4\x1d\xc6q\xbc\xae\xc2<W\x10\x04\x1d\xdf\xf7\x97\xc0\
\x9d\xa4A^\x09\xefd\xce\x08\xd8]\xc2\x1c \x8e\xe3\
u\x9a\xa6C`\xefy\xde(\x8f\x1f\x01$\xf5$\xad\
.a~\x0a\x01\xac$\xf5\x0a\x00f\xd6\xaaj\xcf\xbf\
\xd1\x16h\x17\x00\xae\xa5\x1a\xe0\xea\x00~Y\xc29\xa7\
*\x8d\xa2(*\xbc\xba\xf0\x07*P\x03\xd4\x005@\
\xe9;Pvo\xab\xd6\xd5+P\x03\x5c\x1d\xe0x\x08\
%m\x81\x9b_\xf0l\x01\x9b|p\xda\x92%f\xd6\
\x0d\x82\xa0s)\xe7\xc3\xda]3K\x0a\x00\x92\xe6@\
\xd3\xf7\xfd\xe5% &\x93\xc9\xed\xa1-odY\xb6\
\xc8\xe3_\xee\xbas\xee\x19x\x04\xf6\xc0\x8a\xcf\x06\xb2\
\x0a\xb5\x80.\xd0\xa0\xecc\x92+\x0c\xc3\xbe\xe7y\xa3\
C\xeb\xdc>\xcf\xffP\x1b3K\xb2,[\x9c\x7f\xcd\
j}\x00,\x83\x82\xe5\xf9\x1d\x9c\xb3\x00\x00\x00\x00I\
END\xaeB`\x82\
\x00\x00\x01\xa2\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00 \x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\
\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\
\x01\x00\x9a\x9c\x18\x00\x00\x01TIDATX\x85\xed\
\x97Aj\xc2P\x10\x86\xbfI\x8a]V\xa9\x8dg\xc8\
F\xbb\xf2\x04\x05\xbd\x83\xa7\xb0\xe8\xae\xed\xa2.\x0d\xda\
Kx\x86R\xe8\x09\xb2R\xbb\xc8\x19\x14A\xbbTH\
\xa6\x0bc\x10\x83\x0a5\xe9\xa6\xef\xdb\xe5\xbd!\xff\xc7\
<B\xe6\xc1\x7fG\x0e\x17\x1co\xdcP\xb1\x1eU\xa9\
\x03\xc5\x8crV\x22\xf8\xa2\xd1`\xde\xb9\xff8*p\
\xebM{\x02O\xc0\x1a4@\xe5;\x93x\xd1\x1b\x10\
\x17\xb8F\xe9-\xba\xd5\x97\x94\xc0\xdd`\xd2\xd4H\xde\
\x81O[\xb55\xeb\xd6\xe6\x99\x84\xc7T\xfa\x13'\x14\
\x19\x01\x0f\x16Qs\xd7\x09+\xa9Pi\x03\xeb<\xc2\
\x01f\xdd\xda\xdcVm\x01\x9b\x10\xbb\xbd[O\x04\xb6\
g\xaeA\x1e\xe1\xfb\x12@ h=%\x00\x143;\
\xf3S(+\xa0\xb4{\xbc:W_\xf6\xa6zI\xde\
\xa2SM}i\xfbX\xa76\xff\x02#`\x04\x8c\x80\
\x110\x02F\xc0\x08\x9c\x9d\x07\xce\xfd\xcf/e\xbf\x03\
\xab\xed\xf4\x9a3B\x11X\xa6\x04D\xf0A\xdcJ\x7f\
\xe2\xe4\x95\x1d\xbf\xdbU\xc4O\x0bh4\x00\xaeC\x91\
Q\x1e\x12\xce\xdbW%\x1e\xcb\x0b6\xe10\xc9\xdd/\
*\xf7\xa7\xaf\x08\xcf\xc0\x06\x08\xe2\x01\xf2r\xb6mw\
\x81\xc2\xd1\x8bIb\xea\x8d\x1b!v;\x1e\x9dK\x87\
\xfb\xbfd\xa9\x88o\x13\x0e\x0f\xaff\x86\x1f\xb5\xcbt\
\xcbLX\x91c\x00\x00\x00\x00IEND\xaeB`\
\x82\
\x00\x00\x00\xa6\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00\x09\x00\x00\x00\x06\x08\x04\x00\x00\x00\xbb\xce|N\
\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\
\x02bKGD\x00\x9cS4\xfc]\x00\x00\x00\x09p\
HYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\
\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x0b\x1b\x0e\x16\
M[o\x00\x00\x00*IDAT\x08\xd7c`\xc0\
\x00\x8c\x0c\x0cs> \x0b\xa4\x08020 \x0b\xa6\
\x08000B\x98\x10\xc1\x14\x01\x14\x13P\xb5\xa3\x01\
\x00\xc6\xb9\x07\x90]f\x1f\x83\x00\x00\x00\x00IEN\
D\xaeB`\x82\
\x00\x00\x00\xa6\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00\x09\x00\x00\x00\x06\x08\x04\x00\x00\x00\xbb\xce|N\
\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\
\x02bKGD\x00\xff\x87\x8f\xcc\xbf\x00\x00\x00\x09p\
HYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\
\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x08\x15;\xdc\
;\x0c\x9b\x00\x00\x00*IDAT\x08\xd7c`\xc0\
\x00\x8c\x0c\x0cs> \x0b\xa4\x08020 \x0b\xa6\
\x08000B\x98\x10\xc1\x14\x01\x14\x13P\xb5\xa3\x01\
\x00\xc6\xb9\x07\x90]f\x1f\x83\x00\x00\x00\x00IEN\
D\xaeB`\x82\
\x00\x00\x00\xdc\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00\x10\x00\x00\x00@\x08\x06\x00\x00\x00\x13}\xf7\x96\
\x00\x00\x00\x06bKGD\x00\xb3\x00y\x00y\xdc\xdd\
S\xfc\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\
\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\
\xdf\x04\x19\x10-\x19\xafJ\xeb\xd0\x00\x00\x00\x1diT\
XtComment\x00\x00\x00\x00\x00Cr\
eated with GIMPd\
.e\x07\x00\x00\x00@IDATX\xc3\xed\xce1\
\x0a\x00 \x0c\x03@\xf5\xa3}[_\xaaS\xc1\xc9\xc5\
E\xe42\x05\x1a\x8e\xb6v\x99^%\x22f\xf5\xcc\xec\
\xfb\xe8t\x1b\xb7\x1f\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\xf06\xf0A\x16\x0bB\x08x\x15WD\xa2\x00\
\x00\x00\x00IEND\xaeB`\x82\
\x00\x00\x00\xa6\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00\x06\x00\x00\x00\x09\x08\x04\x00\x00\x00\xbb\x93\x95\x16\
\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\
\x02bKGD\x00\xff\x87\x8f\xcc\xbf\x00\x00\x00\x09p\
HYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\
\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x14\x1d\x00\xb0\
\xd55\xa3\x00\x00\x00*IDAT\x08\xd7c`\xc0\
\x06\xfe\x9fg``B0\xa1\x1c\x08\x93\x81\x81\x09\xc1\
d``b``4D\xe2 s\x19\x90\x8d@\x02\
\x00d@\x09u\x86\xb3\xad\x9c\x00\x00\x00\x00IEN\
D\xaeB`\x82\
\x00\x00\x02k\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00 \x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\
\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\
\x01\x00\x9a\x9c\x18\x00\x00\x02\x1dIDATX\x85\xed\
\x961O\x13a\x18\xc7\x7f\xcf]7:q%\x01>\
\x80C\xb5\x08\x13N\x12\x16\x1d A\xfb\x1d`\xb6\xa1\
\x12\xa1\x0c\x1d\xc0\xa8=\xe3\xa4\x89\xe1;\x14\x07\x18\xc4\
\xa1\x81\x09&\xa0\xd8&~\x81j\x22\xd7\xa9L\xd0\xf7\
q\xe8\x81\x0c\x5c\xdb\xbb6.\xf6\xbf\xde\xfb\xdc\xffw\
O\xee}\xfe\x0f\x0c4\xd0\xff.\x09u:_\x8a9\
qg^\xd04\xc840\xee?\xa9\x81\x1e)R\xf4\
\x1a\xde\x0e\xf9\xd9\xab\xbe\x03\x0c\xbf;{bY\xfa\x01\
H\x02\xc7\x8a\x1c\xa0\xfa\xb3\xf5\x16\x19\x13\xf410\x05\
T\x0d\xf2\xa2\x9eM}\xeb\x0f\x80\xaa\x8c\xbc/\xaf*\
\xb2)\xc2vS\xed\xf5z\xf6~\xf5NH\xb7\x92\xb4\
\xa5\xb9\xa1\xca3U\xc9y\xd9\x07o\x10\xd1n?\xf2\
N\x8d\xb8\xa7k\x09\xb7|\x99(\x94\x17\xbb\xadI\x14\
\xca\x8b\x09\xb7|\xe9\x14\xceV;\x9dm\xdb\x01\xbf\xed\
_Q\x96\xce_Nlu\x0b\x00\x90p\xcbK\xc0g\
c\xe4i}%\xb5\x17\x1e _\x8a%\xe2\xce\xa9\x08\
?~/O\xa4\xc3\x98\xdf\x82\xd8\x06\xee\x9d7\xbc\x87\
A?\xa6\x15T\xec\xc4\x9dy \xd9T{=\x8a9\
\x80\xc1\xce\x01Ig\xc8\x99\x0b:\x13\x08\xd0\xbaj\x1c\
\x07\xfdp\xdd\xa8U\xab'\x16\x12\xd8\xc1@\x00\x90i\
E\x0e\xa2\x9a_K\xb1\xf6U\xf4Q\x04\x00\xc6o\xee\
yo\x08\xbf\xf8;\xb0B\x01\xfc\x13\xb5\x03\xa8!2\
\xd6\xbb\x85\x8c\x02\xb5\x08\x00z\xe4\x8f\xd7\xde\xec13\
\xa2r\x18\x1a@\x91\x2205\xecV\x92Q\xcd[\xb5\
2i\xd0bh\x00\xaf\xe1\xed\x00U[\x9a\x1bQ\x01\
,\x9a\x9b@\xc5\xbb\xf0vC\x03\x90\x9f\xbd2F2\
\xaa<\x0f\x93\x03\xd7\xf2G\xf1\x82A2\xed\xe2\xb9\xed\
-\xa8\xaf\xa4\xf6\x04\xcd!|\x0a\x15F-\xf3\x8f\xaa\
\x92\xeb\x14\xcb]\xc5\xb1\xe3~\x7f%\xa2\xaf\x81/\x06\
;\xd7.\x8e\xfd\xb6/(\xacy\xcb\xa9\xb7\x9d\xe28\
\xe2B\xa2'\x8a\xb5\xef\x0f\x19@F\x053\x032\x09\
T\x0c\x92\xe9\xdfBr[\xf9R\xcc\x19r\xe6,$\
\xed\x8f\xd7\x9b\x95LT\x0e\x0dZ\xf4.\xbc\xdd0+\
\xd9@\x03\x0d\xf4\x071\xe2\xd8\x82\x22J\xad\xa7\x00\x00\
\x00\x00IEND\xaeB`\x82\
\x00\x00\x00\x96\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00\x09\x00\x00\x00\x06\x08\x04\x00\x00\x00\xbb\xce|N\
\x00\x00\x00\x02bKGD\x00\xd3\xb5W\xa0\x5c\x00\x00\
\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\
\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x0b\x07\x0c\
\x0d\x1bu\xfe1\x99\x00\x00\x00'IDAT\x08\xd7\
e\x8c\xb1\x0d\x00\x00\x08\x83\xe0\xff\xa3up\xb1\xca\xd4\
\x90Px\x08U!\x14\xb6Tp\xe6H\x8d\x87\xcc\x0f\
\x0d\xe0\xf0\x08\x024\xe2+\xa7\x00\x00\x00\x00IEN\
D\xaeB`\x82\
\x00\x00\x03\x18\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00 \x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\
\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\
\x01\x00\x9a\x9c\x18\x00\x00\x02\xcaIDATX\x85\xed\
\x96\xb1o\x14W\x10\xc6\x7f\xdf\xf3\xc9AD\x8eP\xaa\
\x84? \xc55\xc6w\x05\xa4\x81]#\xc5\xc2\xb7@\
\xe4\x0e\xba \xe1\xc2U\xd2\x05L\x89\xa3\xa4Jg%\
\x8a\x94t\xa13\x10\x9f\x8d\x0c\xb29h\x02Rls\
\x05\x96\xf2\x0f8T\x11\x8a\x15\x94\x00\xb7_\x8a\xdb=\
_$\xaf\xedCN\x95\xfb\xaa\xb7\xb33o\xbe\x99\xf7\
\xde\xcc@\x1f}\xfc\xdf\xa1^\x94\xa3(*m1\x94\
X\x9e\x10>n8\x9am\xb2i\xf4X\xd6\xdc\x10[\
\xf5F\xa3\xf1\xfa\xc0\x09TG\xcf~d\xa7_\x03e\
\xa4uH\x1f:\xd5o\x00\x0a~\x1f\xc2I\xec\x11`\
#\x04\x7f\xfa\xcb\xf2\xe2\xbd\x83\x22\xa0J\x5c\xbb\x02\xcc\
`nz \xbd\xb6\xbe|gc'\xc5\x91\xd3g\xca\
j\x85\xeb\x88\x8f\x85\xa6W\xef\xd7\xbf\x04\xbc\xcf\x18w\
F%\xae]\xad\xc4\xb5W\x95\xd1\xe4\xf2\xbemF\x93\
\xcb\x95\xb8\xf6\xaa\x1a'W\xf6\xd2\xdd5\x03Y\xda\x97\
\x90&\xd7V\xea\xdf\xe56\x95(\xb9\x88<\x05\x1e\xce\
DM\xac\xd9\xb5F\xfdG\xb2\x88+qm\x12\xf8V\
\x0ac\xab+\xf3w{&\x10EQ\xe9\x0f\xbd\xdd\xc4\
\xfc\xba\xd6X\x98\x00\xf8pl\xec\xdd\xbf_\x96~\x00\
\xce!\xa5\xd8\xa1\xbdK{m|\xfb\xd0`\xeb\xd2\xcf\
KK\xbf\xb731~\x13\xeb\x83w\xfc\xe7p\xd1\xc5\
\x0cE\x04\xb6\x18J\x80\xb2\x07\xd2k9\xd9\xb6s%\
\x00\x1d\xe7]k\x11\xce\xfe\xf5r\xe0\xfb<0\xcb\xd3\
@\xf9\xb9\x0e\xd7\x8a\xfc\x14\x12\xb0<\x81\xb4\x9e_\xb8\
J\x94\x5c\x04\xce\x81\x0bm\xc0A\xe8|5\x1e\xbf\x00\
\xb0\xbe|gC\xf0d\x00&z& |\x1c\xd2\x87\
\xdb\x02O!\xa5\xc5\xce;\x86i\x8a\xa6\xba\x02y\x00\
:Q\xa4^*\xfaa8\x9a\xbf\xf3L2\x8c\x8b\x09\
w\x19\x06`x\x9b\x0f\xcf\xf2\x82\xb5\x13\xf6\xde\xf0?\
\xc6.G\xc0f\xbb\xc2u$\xcd\xfd\x1e\x01\xd0\xcc?\
\x0d\xef\x096{&`\xf4\x18\xc2\xc9m\x81f\xffu\
\xf3\x8b\x0dC\xc0\xb3\x1d>\xd6)\xf0\xa3\x9e\x09\xc8\x9a\
\xc3\x1e\x199}\xa6\x0c\x90\x15\x99\x9f`\xb7,(5\
\xbe\xbdz\x7f\xf1\x06\xb4K\xb3\xe1X\x0b\xe6z&0\
\xc4V\x1d\xd8P+\x5c\xcfD~k\xf0\xf5'&\x9d\
o\xfbb\x9bH\xb66\xe9\xfc\xa1\xc1\xd6%\xb2j(\
kF\xf0\xf4\x88_,\x14R.\x8e\xa6\xb8\x14W\xe3\
\xf1\x0b\xd9S\xcbo{3\xe0\xd9,\xf2\xeeR\xfcM\
\x08\x1e\xdbog\xdc\x11o\xd4\x8c\xe2\xda\xe4\x814\xa3\
\x5c\xa7\x1a'\x9f\x1b\x7f\x81|\xcb\xf2\xf4\xae\xed\xd8\x9a\
\xc1:/\xf9\xea\xea\xca\xe2W\xec\xd1\x8e\xdfh \x11\
<\xb1\xfc@\xf0\x0c\xb2\xa7f\x9d2\x1c\x13<U\xf0\
g\x079\x90t\x10EQ\xe9\xb9\x0e\xd7\xda\xb5]'\
\xbaG2\xf0\xa3\x16\xcc\x1d\xf1\x8b\x85^F\xb2>\xfa\
\xe8\xe3\x1frx6\x82c\xad\x95\xaf\x00\x00\x00\x00I\
END\xaeB`\x82\
\x00\x00\x0b\x17\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00?\x00\x00\x00\x07\x08\x06\x00\x00\x00\xbfv\x95\x1f\
\x00\x00\x00\x87zTXtRaw prof\
ile type exif\x00\x00x\
\xdaU\x8e\xd1\x0d\xc40\x08C\xff\x99\xe2F @L\
\x18\xa7\xaa\x1a\xe96\xb8\xf1\x0f\x94Vm\xdf\x87\xb1,\
d\xa0\xe3\xf7\x9d\xf4)\x1a\x0bY\xf7\x81\x008\xb1\xb0\
\x90-\xcd\xe0\x8527\xe1V3uqNm\xe9\xe4\
\x8eIe\x19\xc4p\xb6{\xd1\xce\xfc\xa2+\x06\xa6\x9b\
;:v\xec\x92\xedr\xa8\xa8\xa4VQ\xb5r\xbd\x11\
\x8fk\xf3\xfa\xe8\x9d\xb3\xbf\xcb\xe9\x0fH!,K\xed\
~\xc6\xe4\x00\x00\x0a\x00iTXtXML:c\
om.adobe.xmp\x00\x00\x00\x00\
\x00<?xpacket begin\
=\x22\xef\xbb\xbf\x22 id=\x22W5M0M\
pCehiHzreSzNTczk\
c9d\x22?>\x0a<x:xmpmet\
a xmlns:x=\x22adobe\
:ns:meta/\x22 x:xmp\
tk=\x22XMP Core 4.4\
.0-Exiv2\x22>\x0a <rdf\
:RDF xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22>\x0a  \
<rdf:Description\
 rdf:about=\x22\x22\x0a  \
  xmlns:exif=\x22ht\
tp://ns.adobe.co\
m/exif/1.0/\x22\x0a   \
 xmlns:tiff=\x22htt\
p://ns.adobe.com\
/tiff/1.0/\x22\x0a   e\
xif:PixelXDimens\
ion=\x2263\x22\x0a   exif\
:PixelYDimension\
=\x227\x22\x0a   tiff:Ima\
geWidth=\x2263\x22\x0a   \
tiff:ImageHeight\
=\x227\x22\x0a   tiff:Ori\
entation=\x221\x22/>\x0a \
</rdf:RDF>\x0a</x:x\
mpmeta>\x0a        \
                \
                \
                \
                \
                \
            \x0a   \
                \
                \
                \
                \
                \
                \
 \x0a              \
                \
                \
                \
                \
                \
      \x0a         \
                \
                \
                \
                \
                \
           \x0a    \
                \
                \
                \
                \
                \
                \
\x0a               \
                \
                \
                \
                \
                \
     \x0a          \
                \
                \
                \
                \
                \
          \x0a     \
                \
                \
                \
                \
                \
               \x0a\
                \
                \
                \
                \
                \
                \
    \x0a           \
                \
                \
                \
                \
                \
         \x0a      \
                \
                \
                \
                \
                \
              \x0a \
                \
                \
                \
                \
                \
                \
   \x0a            \
                \
                \
                \
                \
                \
        \x0a       \
                \
                \
                \
                \
                \
             \x0a  \
                \
                \
                \
                \
                \
                \
  \x0a             \
                \
                \
                \
                \
                \
       \x0a        \
                \
                \
                \
                \
                \
            \x0a   \
                \
                \
                \
                \
                \
                \
 \x0a              \
                \
                \
                \
                \
                \
      \x0a         \
                \
                \
                \
                \
                \
           \x0a    \
                \
       \x0a<?xpacke\
t end=\x22w\x22?>@\x00Zq\x00\
\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00/IDAT8\xcbc`\x18\x05#\x130\
\xc2\x18\xf1\xf1\xf1\xa4\xe8\xfb?\x98\xfdB\x0cX\xb8p\
!\x03\xd3H\x8e\xf9\x11\xe9\xf9\x85\x0b\x17\x8e\xe6\xf9\x11\
\x0d\x00\x8bl\x05\xe9)K\xfc\x15\x00\x00\x00\x00IE\
ND\xaeB`\x82\
\x00\x00\x00\xa0\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00\x06\x00\x00\x00\x09\x08\x04\x00\x00\x00\xbb\x93\x95\x16\
\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\
\x02bKGD\x00\xff\x87\x8f\xcc\xbf\x00\x00\x00\x09p\
HYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\
\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x14\x1f\x0d\xfc\
R+\x9c\x00\x00\x00$IDAT\x08\xd7c`@\
\x05s>\xc0XL\xc8\x5c&dY&d\xc5pN\
\x8a\x00\x9c\x93\x22\x80a\x1a\x0a\x00\x00)\x95\x08\xaf\x88\
\xac\xba4\x00\x00\x00\x00IEND\xaeB`\x82\
\x00\x00\x02+\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00@\x00\x00\x00@\x08\x06\x00\x00\x00\xaaiq\xde\
\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\
\x00\x00\x01\xe2IDATx\x9c\xed\x9bK\x0e\xc3 \
\x10CiO\x9d#p\xebv\x85\x84\x10\x81\x81\xb1\x0d\
Q\xf0:5\xf1\xe3\x93\x0c%!\x1c\x1d\x1d\xbdY\x1f\
ec\xd7u\xfd,\xd7\xc5\x18e\xf7Em\xc8\x1a\xb8\
'&\x10\xb81*\xf4\x9d\xd00`f\xec\xe0\xa5P\
  &\xea\xf0I\x08\x08.\x83U\xc1Ky@L\
\xffp\x97\xf0I\xb3\x10\x86\x7f\xb4[\xf0R\xa3 \x86\
.\xde=|\xd2\x08\x04\xf3\x85O\x09\x9fd\x85\xf0e\
\xdf\xc8\xee2QzZ\xef'YFA\xf7\x82^\xf8\
\xbc\x11\x15\xa82X\xab\xdd\x1e\x04\xe8\x14\x881~\xd8\
\x85\x0c\xda\xbf\x09`\xb6GY\x10f|{\x19n\x01\
x\x873\x1a\x82\xc7\xaf\x95\xc5=\x05<\xf3\xcf\xaa\x96\
\x8f\xb7\xa3\xaa\xc63\xa6\xac\x9bD\xfa\xd6\xbc`\x8b \
c$0{>\x09\xfa\x14@BP\x84\x0f\xa12\x05\
\x10\xe6\xde\x9bg\x86/\xbd)\xaf\xc2\x9e\x91\xa0\xea\xf9\
$Z-0\x03A\x1d>\x04r14\x02aE\xf8\
\x10\x8a5\x80\xd5P/\x9c:|\xde\x9e\xa4\x1c\x9e]\
\x13\x14\xc5\x95l?`4\x8c\xaa\xb2\x94n\x88XC\
)\xf7\x1f\xe4;B\xbdp\xea\xcd\x179\x00\xcf{\x00\
CR\x00\xd6pJ\x082\x00\xc8Z\x00)\x09\x80\xd9\
G\x9d\x02\x02\x1d\x80%\xfcJ\x08\x94j0i\xb4\xe7\
\x15/E\x92j\xb0\xd6P\xae\xbb0+F\x02\x05\x80\
\xa7'\xd5\x10\xe0\x00\x10\xc3X\x09\x01\xb6)\x1a\x02~\
\x0e+\xfc`#\x80\xb1\x80)F\x02\x04\x00s\xf5f\
Cp\xdf\xb8\xaa\x9egm\xb4.\xd9\x13\xdc\xc1/\xe9\
\x16\x00\xeb\xbf8\x8f\x18\x8b3|\x04\xb0\xeby\xb4\xbf\
\xfb\x80\xc4\xee\xea\x8d\xe4sD\xc6j\xf64\x08\xe7\x94\
\x98Q\xe7\xa0\xe4\xa8\xf9\xee\x10\xa8Ges\xed\x06B\
vX:\xd7.\x10\x96\x1c\x97OZ\x0d\xc1[\x10\x9d\
Of\x10&\xb9^\xfb\xd1TM\xaf\xfcl\xae\xa5\x1d\
?\x9c<z\xbb\xfe_XZ\xcd\xa5\xce{\xda\x00\x00\
\x00\x00IEND\xaeB`\x82\
\x00\x00\x00\xa0\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00\x06\x00\x00\x00\x09\x08\x04\x00\x00\x00\xbb\x93\x95\x16\
\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\
\x02bKGD\x00\x9cS4\xfc]\x00\x00\x00\x09p\
HYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\
\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x0b\x1b)\xb3\
G\xee\x04\x00\x00\x00$IDAT\x08\xd7c`@\
\x05s>\xc0XL\xc8\x5c&dY&d\xc5pN\
\x8a\x00\x9c\x93\x22\x80a\x1a\x0a\x00\x00)\x95\x08\xaf\x88\
\xac\xba4\x00\x00\x00\x00IEND\xaeB`\x82\
\x00\x00\x01\x8d\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00 \x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\
\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\
\x01\x00\x9a\x9c\x18\x00\x00\x01?IDATX\x85\xed\
\x97Aj\xc2@\x14\x86\xbf\x17\x82.\x8d\x1b{\x86\x5c\
\xc0\x13\x14\xf4\x0e\x9e\xc2\x12H\x94\xb6\x8b\xbaQ\x08z\
\x0a\xcfP\x0a=A.\x90;\xb8\xd1.\x95\x90\xbf\x8b\
\x9ab\x15)\x94\xa4]t\xbe\xd5\xe4\xcd\x90\xffcf\
\xf3\x1e\xfcw\xec\xbc\x10\xc7\xf1\xc0\xcc\xee$\xf5\xcd,\
\xa8#D\xd2\xce\xcc2I\xcb\xc5b\xf1rU`2\
\x99\xcc$\xdd\x03{I\xb9\x99\xbd\xd5$\xd01\xb3\x10\
h\x03\xb3\xf9|\xfex!\x90$\xc9\x10x\x06^\x8b\
\xa2\x18\xa5i\xba\xa9#\xbc\x22\x8a\xa2\x9e\xef\xfbk\xe0\
V\xd2\xb0\xba\x09\xef\xe4\xcc\x18\xd87\x11\x0e\x90\xa6\xe9\
\xa6(\x8a\x11p\xf0<o\x5c\xd5?\x05$\xf5%\xe5\
M\x84\x9fJ\x00\xb9\xa4\xfe\x85\x80\x99\x05u\xbd\xf97\
\xec\x80\xee\x85\xc0_\xe1\x04\x9c\x80\x13p\x02N\xc0\x09\
8\x01'\xe0W\x0bI;\xa0\xf3\x0b\x99\x01\xb0\xad>\
N[\xb2\xcc\xcc\xc2(\x8azM%\x1f\xff\x1d\x9aY\
v! i\x09\xb4}\xdf_7!1\x9dNo\x8e\
my\xab,\xcbUU\xff2\x98$I\xf2\x04<\x00\
\x07 \xe7\xa3\x81\xac\x83\x00\x08\x81\x16\xd7\x06\x93\x8a8\
\x8e\x07\x9e\xe7\x8d\x8f\xads\xf7|\xff\x87l\xcd,+\
\xcbru>\x9a9\xde\x01#\x94}H\x8c\x1a5\x0f\
\x00\x00\x00\x00IEND\xaeB`\x82\
\x00\x00\x00\xa5\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00\x09\x00\x00\x00\x06\x08\x04\x00\x00\x00\xbb\xce|N\
\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\
\x02bKGD\x00\x9cS4\xfc]\x00\x00\x00\x09p\
HYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\
\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x0b\x02\x04m\
\x98\x1bi\x00\x00\x00)IDAT\x08\xd7c`\xc0\
\x00\x8c\x0c\x0c\xff\xcf\xa3\x08\x18220 \x0b2\x1a\
200B\x98\x10AFC\x14\x13P\xb5\xa3\x01\x00\
\xd6\x10\x07\xd2/H\xdfJ\x00\x00\x00\x00IEND\
\xaeB`\x82\
\x00\x00\x00\x9e\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00\x09\x00\x00\x00\x06\x08\x04\x00\x00\x00\xbb\xce|N\
\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\
\x02bKGD\x00\xff\x87\x8f\xcc\xbf\x00\x00\x00\x09p\
HYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\
\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x08\x15\x0f\xfd\
\x8f\xf8.\x00\x00\x00\x22IDAT\x08\xd7c`\xc0\
\x0d\xfe\x9f\x87\xb1\x18\x91\x05\x18\x0d\xe1BH*\x0c\x19\
\x18\x18\x91\x05\x10*\xd1\x00\x00\xca\xb5\x07\xd2v\xbb\xb2\
\xc5\x00\x00\x00\x00IEND\xaeB`\x82\
\x00\x00\x02\xa1\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00 \x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\
\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\
\x01\x00\x9a\x9c\x18\x00\x00\x02SIDATX\x85\xed\
\x96\xbfO\x13a\x18\xc7?\xcf\xb5\x13\xa6\x86\xd1v\xa3\
\x03\x90.\xd2\xeb\x00\x13\x5cKB\x82W\xa2av\xc5\
8j\xe2 ?\xdc\xa8\xd1\xc4D\x17'\x06\xe3?P\
\x1cZ\x18\x08P\x18\x14\x12iq\xa0\x89\x0d\xa4L-\
n\xc4F\x16\xec=\x0e\x80a\xe0\xe0\xae\x10\x17\xfbY\
\xdf\xef{\xdf\xef\xdd\xbd\xef\xf3<\xd0\xa6\xcd\xff\x8e\xf8\
\x11[\x96\x15l\x10J\xab\xe8\xb8\xa0\xfd\x0a\x91\xd3\x87\
\xd4\x14\xd9\x14\x95l\x88F\xaeP(\xfc\xbe\xf1\x00\x89\
\xd4\xd8\x88\xaa\xf3\x16\x88!R\x02g]\x1d\xa9\x03\x88\
\xa1a0\x06Q\x8d\x03e\xc3\xd0'_\x97\x17\x96n\
*\x80\x98I{\x12\xc8\xa0\xcck\xc0\x99)-/\x96\
/\x12\xc6\x87Gc\xd24f\x11\x1e\x082\xbd\xb5\x9a\
{\x05\xa8\xc7w\xbc\x183iO\x99I\xfb\xd8L\xa5\
'<\xefI\xa5'\xcc\xa4}\x9cH\xa6'\xaf\xd2\x06\
.[L\xa4\xc6F@? \xf2\xb8\xb8\x92\x9b\xf3\x1a\
\xa0^\xad\x14\xc3]\xdd?\x80w\x91h\xef\x97z\xb5\
\xb2\xe7\xa6u\xfd\x05\x96e\x05\x7f\xca\xado(\xdf\x8b\
\x85\xfc\xb8W\xf3\xf3\x98\xa9{\xf3\xa8t\xdf\xd6_w\
\xdd\x0e\xa6\xe1\xb6\xb9A(\x0d\xc44\xe0\xcc\xb4b\x0e\
\xa0\xa2\xd3@\xecP:l7\x8dk\x00\x15\x1dG\xa4\
\xe4v\xe0\xbcPZ^,\x0bl\x07\xc0\xf5\x0b\xba\x06\
\x10\xb4\x1f\x9c\xf5V\xcd\xcfP\xd15\x90\x01\xdf\x01\x14\
\x22g\xf7\xfc:\x08\x1c\x9c\x15,_\x01\xfe\x15A\xb7\
\x05\x81\x1a\x86\x86\xafk\xa0pG\xa0\xe6;\x80\x22\x9b\
 \x83\xd7\x0d *C\xa0\x1bn\xeb\xee\x87P%\x8b\
j<><\x1ak\xd5<><\x1aS\xe8kB\xd6\
w\x80\x10\x8d\x1cP\x96\xa61\xdbj\x00Q\xc9\x08\xec\
t\xeaQ\xdeM\xe3Z\x8a\xf7\xf7\xf7\x9dH\xb4w\x17\
4\x13\x8e\xf6\xd4\xea\xd5J\xd1\x8f\xb9\x99\xb4\x1f\x81<\
3\x0c}\xf8yui\xd7w\x00\x80z\xb5\xb2\x17\xee\
\xea>\x06\xde\x84\xa3=\x07^C\x9c\x98\xf3^\x90\x17\
[+\xf9\x8f\x97i=\xb5\xe3D2\xfd\x5c\xd1\x97\x88\
~R\xd1\xe9K\xdb\xb1J\x06\x95\xfb\x22:\xb5\xb5\xb2\
\xf0\x9a+\xdaqK\x03\x89\xc0\xb6\x8a\xae\x09\x1c\xc0\xe9\
US\x19R\xe8\x13\xd8\x11C\x9f\xde\xe4@\xf2\x17\xcb\
\xb2\x82\x87\xd2a\x9f\xd4v\x198?\x92\x81n4!\
\xdb\xa9Gy?#Y\x9b6m\xfe\x00\x0aI\xe7\x8d\
\x0aU\xe0c\x00\x00\x00\x00IEND\xaeB`\x82\
\
\x00\x00\x00\x9f\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00\x09\x00\x00\x00\x06\x08\x04\x00\x00\x00\xbb\xce|N\
\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\
\x02bKGD\x00\xff\x87\x8f\xcc\xbf\x00\x00\x00\x09p\
HYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\
\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x08\x14\x1f\xf9\
#\xd9\x0b\x00\x00\x00#IDAT\x08\xd7c`\xc0\
\x0d\xe6|\x80\xb1\x18\x91\x05R\x04\xe0B\x08\x15)\x02\
\x0c\x0c\x8c\xc8\x02\x08\x95h\x00\x00\xac\xac\x07\x90Ne\
4\xac\x00\x00\x00\x00IEND\xaeB`\x82\
\x00\x00\x01\xa4\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00 \x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\
\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\
\x01\x00\x9a\x9c\x18\x00\x00\x01VIDATX\x85\xed\
\x97Aj\xc2@\x14\x86\xbfg\x8a.\xab\xd4\xc63d\
\xa3]y\x82\x82\xde\xc1SXt\xd7v\xa1K\x83\xf6\
\x12\x9e\xa1\x14z\x82\xac\xd4.r\x06E\xd0.\x15\x92\
\xd7\x851H\xd2t\xd1&(4\xdfrf\x98\xff\xe3\
\x0d3\xbc\x81\xff\x8eD\x07L{\xd6R)<\xa8\xd2\
\x04\xca)\xe5lEpD\xfd\xf1\xaaw\xf7\x96(p\
c/\x86\x02\x8f\xc0\x0e\xd4E\xe53\x95x\xd1k\x10\
\x0b(\xa1\x0c\xd7\xfd\xfasL\xe0v<o\xab/\xaf\
\xc0\xbb\xa1\xdaY\xf6\x1b\xabT\xc2\x03j\xa3\xb9\xe9\x89\
L\x81\xfb\x02~\xfbX\x89B\xb8B\xa5\x0b\xec\xb2\x08\
\x07X\xf6\x1b+C\xb5\x03\xec=\x8c\xeeq<\x148\
\x9c\xb9\xbaY\x84\x9fJ\x00\xae\xa0\xcd\x98\x00PN\xed\
\xcc\x7fB\xd9\x02\x95\xef\x04\xceB.pv\x81\xab\xa4\
\x89\xaa\xbd\xd04\x83\xd6\xbdz\xec\xd5\x85\x0b\xa8@.\
\x90\x0b\xe4\x02\x89\xef@\xd2\xbdM\x9b\xb3W \x17\xb8\
(\x81\xed\xa1{\xcd\x18\xa1\x0clb\x02\x228 V\
m47\xb3\xca\x0e\xf6\xb6\x14q\xe2\x02\xea\x8f\x81\x92\
'2\xcdB\xc2|\xf9\xa8\x05my\xd1\xc0\x9b\x84\xb9\
\xa7\x8b\xaa\xa3\xc5\x00\xe1\x09\xd8\x03n\xd0@\xfe\x9dC\
\xd9-\xa0\x98\xf81\x09M\xedY\xcb\xc3\xe8\x06\xads\
%:\xffK6\x8a8\x06\xde$\xfa5\xcb\xf9\x02\xdd\
Dt\xcbi%\xf5\xbc\x00\x00\x00\x00IEND\xae\
B`\x82\
\x00\x00\x00\xa6\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00\x06\x00\x00\x00\x09\x08\x04\x00\x00\x00\xbb\x93\x95\x16\
\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\
\x02bKGD\x00\xff\x87\x8f\xcc\xbf\x00\x00\x00\x09p\
HYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\
\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x14\x1f \xb9\
\x8dw\xe9\x00\x00\x00*IDAT\x08\xd7c`\xc0\
\x06\xe6|```B0\xa1\x1c\x08\x93\x81\x81\x09\xc1\
d``b`H\x11@\xe2 s\x19\x90\x8d@\x02\
\x00#\xed\x08\xafd\x9f\x0f\x15\x00\x00\x00\x00IEN\
D\xaeB`\x82\
\x00\x00\x02\x84\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00 \x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\
\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\
\x01\x00\x9a\x9c\x18\x00\x00\x026IDATX\x85\xed\
\x96\xb1N\x14Q\x14\x86\xbf3\x92,\xfb\x06\xc8\x03X\
l#T\x920+\x1d\x0d$\x1aj[\x89\xb1\xd2\xc4\
d\xee\x054c\xe283\xc4D\x1bm,\x8c/\xb0\
X@e\xb3\x90I\x84\x06\xb4`\x13\x13h\x11\x9f`\
\xd9h\xee\xb1`\x10L\x9c\xcd\xce.\xb1q\xbf\xf6\xfc\
3\xe7\xcf\xcd=\xff=0d\xc8\xff\x8e\x94\x11\x87a\
8\xd2\xe9t\xe6Uu\x01\xb8\x01\x8c\xe7\xa5#`G\
D\x1a\x95Je=\x0c\xc3\x9f\x97n\xc0\x183\x0b\xbc\
\x04j\xc0\x1e\xb0\x05|\xcb\xcbW\x81\x9b\xc0$\xd0r\
\xce=X]]\xfdxY\x06$\x08\x02+\x22\x11\xb0\
&\x22+q\x1c\xb7\xfe&\xb4\xd6\xd6T\xf5\x19p\x1b\
XN\x92$\x01t \x03A\x10,\x89\xc8S\x11\xb9\
\x1f\xc7\xf1\xdb\x1e\x0cc\xad\xbd\xab\xaao\x80'I\x92\
\xc4\xdd\xb4W\xba\x15\x8d1\xb3\x22\xf2ND\xee\xf5\xda\
\x1c \xcb\xb2]\xdf\xf7\xbf\x03\xaf|\xdf\xff\x94e\xd9\
a\x91\xb6\xf0\x04\xc20\x1c999\xf9\x02|M\x92\
d\xa1\xd7\xe6\x17\x09\x82`MD\xae\x8d\x8e\x8e^/\
\xba\x98^\xd1\xc7\x9dNg\x1e\xa8\x89\xc8J?\xcd\x01\
<\xcf[\x06j\xedv{\xaePST\xc8Gm\xaf\
\xe8\xc2\xf5B\x1c\xc7-U\xfd,\x22\x85'Xh\x80\
\xd39\xdf\xea\xb7\xf9\x19\x22\xb2\x09L\xf5c`\x9c\xf3\
9\xef\x1bU=\xe6<\xb0J\x19\xf8't3p\xc4\
i\xc2\x0d\x84\x88\x8c\xe5\xff*m`\x87\xd3x\x1d\x08\
U\x9d\x01\xb6K\x1b\x10\x91\x060i\xad\xad\xf5\xdb\xdc\
Z[\x13\x91\x09Um\x946P\xa9T\xd6\x81V\x9e\
\xed}\xe1\x9c\x8b\x80\xfdj\xb5\xbaQ\xa4)\x8c\xe2f\
\xb3\xe9|\xdf?\x00\xa2z\xbd~\x94e\xd9n\x99\xe6\
\xc6\x98E\x11y\xe4\x9c\xbb\x13E\xd1Ai\x03\x00Y\
\x96\x1dNOO\xff\x00^\xd4\xeb\xf5\xe3^M\x18c\
\x16\x81\xd7\xc0\xe34M\xdfw\xd3\xf6\xf4\x1c\x1bc\x0c\
\xf0\x5cU?x\x9e\xb7\xdc\xed9v\xceE\x22rK\
U\x97\xd24M\x19\xf49>\xe3\xe2B\x92\xc7\xebf\
\x1e2\x88\xc8\x98\xaa\xce\x88\xc8\x04\xb0\xef\x9c{x\x99\
\x0b\xc9o\xc20\x1ci\xb7\xdbsy\xb6O\xf1\xe7J\
\xb6\xad\xaa\x8dj\xb5\xbaQf%\x1b2d\xc8/\xff\
B\xe0?O\xfa\x9f\x03\x00\x00\x00\x00IEND\xae\
B`\x82\
"

qt_resource_name = b"\
\x00\x09\
\x09_\x97\x13\
\x00q\
\x00s\x00s\x00_\x00i\x00c\x00o\x00n\x00s\
\x00\x0a\
\x09$M%\
\x00q\
\x00d\x00a\x00r\x00k\x00s\x00t\x00y\x00l\x00e\
\x00\x09\
\x00(\xad#\
\x00s\
\x00t\x00y\x00l\x00e\x00.\x00q\x00s\x00s\
\x00\x02\
\x00\x00\x07\x83\
\x00r\
\x00c\
\x00\x11\
\x0a\xe5l\x07\
\x00r\
\x00a\x00d\x00i\x00o\x00_\x00c\x00h\x00e\x00c\x00k\x00e\x00d\x00.\x00p\x00n\x00g\
\
\x00\x0f\
\x0c\xe2hg\
\x00t\
\x00r\x00a\x00n\x00s\x00p\x00a\x00r\x00e\x00n\x00t\x00.\x00p\x00n\x00g\
\x00\x14\
\x06^,\x07\
\x00b\
\x00r\x00a\x00n\x00c\x00h\x00_\x00c\x00l\x00o\x00s\x00e\x00d\x00-\x00o\x00n\x00.\
\x00p\x00n\x00g\
\x00\x1c\
\x08?\xdag\
\x00c\
\x00h\x00e\x00c\x00k\x00b\x00o\x00x\x00_\x00u\x00n\x00c\x00h\x00e\x00c\x00k\x00e\
\x00d\x00_\x00f\x00o\x00c\x00u\x00s\x00.\x00p\x00n\x00g\
\x00\x1f\
\x0a\xae'G\
\x00c\
\x00h\x00e\x00c\x00k\x00b\x00o\x00x\x00_\x00u\x00n\x00c\x00h\x00e\x00c\x00k\x00e\
\x00d\x00_\x00d\x00i\x00s\x00a\x00b\x00l\x00e\x00d\x00.\x00p\x00n\x00g\
\x00\x0f\
\x01\xf4\x81G\
\x00c\
\x00l\x00o\x00s\x00e\x00-\x00h\x00o\x00v\x00e\x00r\x00.\x00p\x00n\x00g\
\x00\x14\
\x0b\xc5\xd7\xc7\
\x00s\
\x00t\x00y\x00l\x00e\x00s\x00h\x00e\x00e\x00t\x00-\x00v\x00l\x00i\x00n\x00e\x00.\
\x00p\x00n\x00g\
\x00\x1a\
\x01!\xebG\
\x00s\
\x00t\x00y\x00l\x00e\x00s\x00h\x00e\x00e\x00t\x00-\x00b\x00r\x00a\x00n\x00c\x00h\
\x00-\x00m\x00o\x00r\x00e\x00.\x00p\x00n\x00g\
\x00\x0c\
\x06A@\x87\
\x00s\
\x00i\x00z\x00e\x00g\x00r\x00i\x00p\x00.\x00p\x00n\x00g\
\x00\x0a\
\x05\x95\xde'\
\x00u\
\x00n\x00d\x00o\x00c\x00k\x00.\x00p\x00n\x00g\
\x00\x11\
\x08\x8cj\xa7\
\x00H\
\x00s\x00e\x00p\x00a\x00r\x00t\x00o\x00o\x00l\x00b\x00a\x00r\x00.\x00p\x00n\x00g\
\
\x00\x11\
\x08\x90\x94g\
\x00c\
\x00l\x00o\x00s\x00e\x00-\x00p\x00r\x00e\x00s\x00s\x00e\x00d\x00.\x00p\x00n\x00g\
\
\x00\x10\
\x01\x07J\xa7\
\x00V\
\x00m\x00o\x00v\x00e\x00t\x00o\x00o\x00l\x00b\x00a\x00r\x00.\x00p\x00n\x00g\
\x00\x17\
\x0f\x1e\x9bG\
\x00r\
\x00a\x00d\x00i\x00o\x00_\x00c\x00h\x00e\x00c\x00k\x00e\x00d\x00_\x00f\x00o\x00c\
\x00u\x00s\x00.\x00p\x00n\x00g\
\x00\x1d\
\x09\x07\x81\x07\
\x00c\
\x00h\x00e\x00c\x00k\x00b\x00o\x00x\x00_\x00c\x00h\x00e\x00c\x00k\x00e\x00d\x00_\
\x00d\x00i\x00s\x00a\x00b\x00l\x00e\x00d\x00.\x00p\x00n\x00g\
\x00\x14\
\x07\xec\xd1\xc7\
\x00c\
\x00h\x00e\x00c\x00k\x00b\x00o\x00x\x00_\x00c\x00h\x00e\x00c\x00k\x00e\x00d\x00.\
\x00p\x00n\x00g\
\x00\x0f\
\x02\x9f\x05\x87\
\x00r\
\x00i\x00g\x00h\x00t\x00_\x00a\x00r\x00r\x00o\x00w\x00.\x00p\x00n\x00g\
\x00\x19\
\x08>\xcc\x07\
\x00s\
\x00t\x00y\x00l\x00e\x00s\x00h\x00e\x00e\x00t\x00-\x00b\x00r\x00a\x00n\x00c\x00h\
\x00-\x00e\x00n\x00d\x00.\x00p\x00n\x00g\
\x00\x1a\
\x01\x87\xaeg\
\x00c\
\x00h\x00e\x00c\x00k\x00b\x00o\x00x\x00_\x00i\x00n\x00d\x00e\x00t\x00e\x00r\x00m\
\x00i\x00n\x00a\x00t\x00e\x00.\x00p\x00n\x00g\
\x00\x1a\
\x05\x11\xe0\xe7\
\x00c\
\x00h\x00e\x00c\x00k\x00b\x00o\x00x\x00_\x00c\x00h\x00e\x00c\x00k\x00e\x00d\x00_\
\x00f\x00o\x00c\x00u\x00s\x00.\x00p\x00n\x00g\
\x00\x0f\
\x06S%\xa7\
\x00b\
\x00r\x00a\x00n\x00c\x00h\x00_\x00o\x00p\x00e\x00n\x00.\x00p\x00n\x00g\
\x00\x17\
\x0c\xabQ\x07\
\x00d\
\x00o\x00w\x00n\x00_\x00a\x00r\x00r\x00o\x00w\x00_\x00d\x00i\x00s\x00a\x00b\x00l\
\x00e\x00d\x00.\x00p\x00n\x00g\
\x00\x10\
\x01\x00\xca\xa7\
\x00H\
\x00m\x00o\x00v\x00e\x00t\x00o\x00o\x00l\x00b\x00a\x00r\x00.\x00p\x00n\x00g\
\x00\x0e\
\x0e\xde\xfa\xc7\
\x00l\
\x00e\x00f\x00t\x00_\x00a\x00r\x00r\x00o\x00w\x00.\x00p\x00n\x00g\
\x00\x19\
\x0bYn\x87\
\x00r\
\x00a\x00d\x00i\x00o\x00_\x00u\x00n\x00c\x00h\x00e\x00c\x00k\x00e\x00d\x00_\x00f\
\x00o\x00c\x00u\x00s\x00.\x00p\x00n\x00g\
\x00\x12\
\x07\x8f\x9d'\
\x00b\
\x00r\x00a\x00n\x00c\x00h\x00_\x00o\x00p\x00e\x00n\x00-\x00o\x00n\x00.\x00p\x00n\
\x00g\
\x00\x1a\
\x0e\xbc\xc3g\
\x00r\
\x00a\x00d\x00i\x00o\x00_\x00c\x00h\x00e\x00c\x00k\x00e\x00d\x00_\x00d\x00i\x00s\
\x00a\x00b\x00l\x00e\x00d\x00.\x00p\x00n\x00g\
\x00\x11\
\x08\xc4j\xa7\
\x00V\
\x00s\x00e\x00p\x00a\x00r\x00t\x00o\x00o\x00l\x00b\x00a\x00r\x00.\x00p\x00n\x00g\
\
\x00\x18\
\x03\x8e\xdeg\
\x00r\
\x00i\x00g\x00h\x00t\x00_\x00a\x00r\x00r\x00o\x00w\x00_\x00d\x00i\x00s\x00a\x00b\
\x00l\x00e\x00d\x00.\x00p\x00n\x00g\
\x00\x09\
\x06\x98\x83'\
\x00c\
\x00l\x00o\x00s\x00e\x00.\x00p\x00n\x00g\
\x00\x11\
\x0b\xda0\xa7\
\x00b\
\x00r\x00a\x00n\x00c\x00h\x00_\x00c\x00l\x00o\x00s\x00e\x00d\x00.\x00p\x00n\x00g\
\
\x00\x16\
\x01u\xcc\x87\
\x00c\
\x00h\x00e\x00c\x00k\x00b\x00o\x00x\x00_\x00u\x00n\x00c\x00h\x00e\x00c\x00k\x00e\
\x00d\x00.\x00p\x00n\x00g\
\x00\x0e\
\x04\xa2\xfc\xa7\
\x00d\
\x00o\x00w\x00n\x00_\x00a\x00r\x00r\x00o\x00w\x00.\x00p\x00n\x00g\
\x00\x0c\
\x06\xe6\xe6g\
\x00u\
\x00p\x00_\x00a\x00r\x00r\x00o\x00w\x00.\x00p\x00n\x00g\
\x00\x1c\
\x01\xe0J\x07\
\x00r\
\x00a\x00d\x00i\x00o\x00_\x00u\x00n\x00c\x00h\x00e\x00c\x00k\x00e\x00d\x00_\x00d\
\x00i\x00s\x00a\x00b\x00l\x00e\x00d\x00.\x00p\x00n\x00g\
\x00\x15\
\x0f\xf3\xc0\x07\
\x00u\
\x00p\x00_\x00a\x00r\x00r\x00o\x00w\x00_\x00d\x00i\x00s\x00a\x00b\x00l\x00e\x00d\
\x00.\x00p\x00n\x00g\
\x00 \
\x09\xd7\x1f\xa7\
\x00c\
\x00h\x00e\x00c\x00k\x00b\x00o\x00x\x00_\x00i\x00n\x00d\x00e\x00t\x00e\x00r\x00m\
\x00i\x00n\x00a\x00t\x00e\x00_\x00f\x00o\x00c\x00u\x00s\x00.\x00p\x00n\x00g\
\x00\x17\
\x0ce\xce\x07\
\x00l\
\x00e\x00f\x00t\x00_\x00a\x00r\x00r\x00o\x00w\x00_\x00d\x00i\x00s\x00a\x00b\x00l\
\x00e\x00d\x00.\x00p\x00n\x00g\
\x00\x13\
\x08\xc8\x96\xe7\
\x00r\
\x00a\x00d\x00i\x00o\x00_\x00u\x00n\x00c\x00h\x00e\x00c\x00k\x00e\x00d\x00.\x00p\
\x00n\x00g\
"

qt_resource_struct = b"\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x02\x00\x00\x00\x01\
\x00\x00\x00\x18\x00\x02\x00\x00\x00\x01\x00\x00\x00+\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x03\
\x00\x00\x00J\x00\x02\x00\x00\x00'\x00\x00\x00\x04\
\x00\x00\x04T\x00\x00\x00\x00\x00\x01\x00\x00\xcf'\
\x00\x00\x02d\x00\x00\x00\x00\x00\x01\x00\x00\xb7\x81\
\x00\x00\x01\xa2\x00\x00\x00\x00\x00\x01\x00\x00\xb1,\
\x00\x00\x05\xd6\x00\x00\x00\x00\x00\x01\x00\x00\xe5h\
\x00\x00\x03\x88\x00\x00\x00\x00\x00\x01\x00\x00\xca\x81\
\x00\x00\x06H\x00\x00\x00\x00\x00\x01\x00\x00\xe8D\
\x00\x00\x01P\x00\x00\x00\x00\x00\x01\x00\x00\xae\x00\
\x00\x00\x03,\x00\x00\x00\x00\x00\x01\x00\x00\xc8\xf9\
\x00\x00\x05`\x00\x00\x00\x00\x00\x01\x00\x00\xe1\xf1\
\x00\x00\x06\x08\x00\x00\x00\x00\x00\x01\x00\x00\xe6\xf9\
\x00\x00\x03\xc2\x00\x00\x00\x00\x00\x01\x00\x00\xcc-\
\x00\x00\x01\xfa\x00\x00\x00\x00\x00\x01\x00\x00\xb2k\
\x00\x00\x01\xdc\x00\x00\x00\x00\x00\x01\x00\x00\xb1\xe6\
\x00\x00\x03\xfc\x00\x00\x00\x00\x00\x01\x00\x00\xcd\xd3\
\x00\x00\x00\xa0\x00\x00\x00\x00\x00\x01\x00\x00\xaaU\
\x00\x00\x05\x96\x00\x00\x00\x00\x00\x01\x00\x00\xe2\x95\
\x00\x00\x06*\x00\x00\x00\x00\x00\x01\x00\x00\xe7\xa2\
\x00\x00\x04\xd4\x00\x00\x00\x00\x00\x01\x00\x00\xd3 \
\x00\x00\x02\xfe\x00\x00\x00\x00\x00\x01\x00\x00\xc7S\
\x00\x00\x03P\x00\x00\x00\x00\x00\x01\x00\x00\xc9\x9d\
\x00\x00\x00\xce\x00\x00\x00\x00\x00\x01\x00\x00\xaa\xec\
\x00\x00\x02\x14\x00\x00\x00\x00\x00\x01\x00\x00\xb4\x98\
\x00\x00\x02<\x00\x00\x00\x00\x00\x01\x00\x00\xb5H\
\x00\x00\x058\x00\x00\x00\x00\x00\x01\x00\x00\xd6\xd6\
\x00\x00\x070\x00\x00\x00\x00\x00\x01\x00\x00\xed\xde\
\x00\x00\x02\xbe\x00\x00\x00\x00\x00\x01\x00\x00\xc5\xb2\
\x00\x00\x06\xb6\x00\x00\x00\x00\x00\x01\x00\x00\xeb\x8c\
\x00\x00\x01\x0c\x00\x00\x00\x00\x00\x01\x00\x00\xacz\
\x00\x00\x00T\x00\x00\x00\x00\x00\x01\x00\x00\xa6\xa9\
\x00\x00\x04\x9c\x00\x00\x00\x00\x00\x01\x00\x00\xd0\xb1\
\x00\x00\x01t\x00\x00\x00\x00\x00\x01\x00\x00\xb09\
\x00\x00\x05\xae\x00\x00\x00\x00\x00\x01\x00\x00\xe4\xc4\
\x00\x00\x06\xfc\x00\x00\x00\x00\x00\x01\x00\x00\xed4\
\x00\x00\x04 \x00\x00\x00\x00\x00\x01\x00\x00\xce}\
\x00\x00\x00|\x00\x00\x00\x00\x00\x01\x00\x00\xa9\x8e\
\x00\x00\x04\xfe\x00\x00\x00\x00\x00\x01\x00\x00\xd3\xba\
\x00\x00\x04z\x00\x00\x00\x00\x00\x01\x00\x00\xd0\x07\
\x00\x00\x02\x8a\x00\x00\x00\x00\x00\x01\x00\x00\xc2\xa4\
\x00\x00\x06\x86\x00\x00\x00\x00\x00\x01\x00\x00\xea\xe9\
\x00\x00\x002\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\
"

def qInitResources():
    QtCore.qRegisterResourceData(0x01, qt_resource_struct, qt_resource_name, qt_resource_data)

def qCleanupResources():
    QtCore.qUnregisterResourceData(0x01, qt_resource_struct, qt_resource_name, qt_resource_data)

qInitResources()
